@@ -63,12 +63,11 @@ else
 fi
 
 if [ "${HAVE_64}" = 1 ];then
-    ANDROID_API_VERS=21
     LIBDIR=lib64
 else
-    ANDROID_API_VERS=19
     LIBDIR=lib
 fi
+ANDROID_API_VERS=21
 ANDROID_API=android-$ANDROID_API_VERS
 
 export ANDROID_TOOLCHAIN="`pwd`/android-toolchain-$ANDROID_API_VERS-$PLATFORM_SHORT_ARCH"
@@ -114,22 +113,14 @@ if [ ! -d "$DAEMON_DIR" ]; then
     exit 1
 fi
 
-EXTRA_CFLAGS="${EXTRA_CFLAGS} -O3"
-
 # Setup LDFLAGS
-if [ ${ANDROID_ABI} = "armeabi-v7a-hard" ] ; then
-    EXTRA_CFLAGS="${EXTRA_CFLAGS} -march=armv7-a -mfloat-abi=softfp -mfpu=vfpv3-d16"
-    EXTRA_LDFLAGS="-march=armv7-a -mfpu=vfpv3-d16 -mcpu=cortex-a8 -lm_hard -D_NDK_MATH_NO_SOFTFP=1"
-elif [ ${ANDROID_ABI} = "armeabi-v7a" ] ; then
-    EXTRA_CFLAGS="${EXTRA_CFLAGS} -march=armv7-a -mthumb -mfloat-abi=softfp -mfpu=vfpv3-d16"
-    EXTRA_LDFLAGS="-march=armv7-a -mthumb -mfloat-abi=softfp -mfpu=vfpv3-d16"
+if [ ${ANDROID_ABI} = "armeabi-v7a" ] ; then
+    EXTRA_CFLAGS="${EXTRA_CFLAGS} -march=armv7-a -mthumb"
+    EXTRA_LDFLAGS="${EXTRA_LDFLAGS} -march=armv7-a -mthumb"
 elif [ ${ANDROID_ABI} = "arm64-v8a" ] ; then
     EXTRA_LDFLAGS="${EXTRA_LDFLAGS} -L${ANDROID_TOOLCHAIN}/sysroot/usr/lib -L${ANDROID_TOOLCHAIN}/${TARGET_TUPLE}/lib"
 fi
-EXTRA_LDFLAGS="${EXTRA_LDFLAGS} -L${ANDROID_TOOLCHAIN}/${TARGET_TUPLE}/${LIBDIR}/${ANDROID_ABI} -L${ANDROID_TOOLCHAIN}/${TARGET_TUPLE}/${LIBDIR} -lm -latomic -landroid_support"
-
-EXTRA_CXXFLAGS="${EXTRA_CFLAGS}"
-EXTRA_CFLAGS="-std=c11 ${EXTRA_CFLAGS}"
+EXTRA_LDFLAGS="${EXTRA_LDFLAGS} -L${ANDROID_TOOLCHAIN}/${TARGET_TUPLE}/${LIBDIR}/${ANDROID_ABI} -L${ANDROID_TOOLCHAIN}/${TARGET_TUPLE}/${LIBDIR}"
 
 # Make in //
 UNAMES=$(uname -s)
@@ -173,30 +164,28 @@ mkdir -p contrib/${TARGET_TUPLE}/lib/pkgconfig
 cd $DAEMON_DIR/contrib/native-${TARGET_TUPLE}
 ../bootstrap --host=${TARGET_TUPLE} --disable-libav --enable-ffmpeg --disable-speexdsp
 
-# Some libraries have arm assembly which won't build in thumb mode
-# We append -marm to the CFLAGS of these libs to disable thumb mode
-[ ${ANDROID_ABI} = "armeabi-v7a" ] && echo "NOTHUMB := -marm" >> config.mak
-[ ${ANDROID_ABI} = "armeabi-v7a-hard" ] && echo "NOTHUMB := -marm" >> config.mak
-
 # Always strip symbols for libring.so remove it if you want to debug the daemon
 STRIP_ARG="-s "
 
-EXTRA_CFLAGS="${EXTRA_CFLAGS} -DNDEBUG "
+EXTRA_CFLAGS="${EXTRA_CFLAGS} -DNDEBUG -fPIC -fno-integrated-as"
+EXTRA_CXXFLAGS="${EXTRA_CXXFLAGS} -DNDEBUG -fPIC"
+EXTRA_LDFLAGS="${EXTRA_LDFLAGS} -L${SYSROOT}/usr/${LIBDIR}"
+
 if [ "${RELEASE}" -eq 1 ]; then
-    echo "Contribs in release mode."
+    echo "Daemon in release mode."
     OPTS=""
 else
-    echo "Contribs in debug mode."
+    echo "Daemon in debug mode."
     OPTS="--enable-debug"
 fi
 
 export SYSROOT=$ANDROID_TOOLCHAIN/sysroot
-echo "EXTRA_CFLAGS= -g -fpic ${EXTRA_CFLAGS}" >> config.mak
-echo "EXTRA_CXXFLAGS= -g -fpic ${EXTRA_CXXFLAGS}" >> config.mak
-echo "EXTRA_LDFLAGS= ${EXTRA_LDFLAGS} -L${SYSROOT}/usr/${LIBDIR}" >> config.mak
+echo "EXTRA_CFLAGS= ${EXTRA_CFLAGS}" >> config.mak
+echo "EXTRA_CXXFLAGS= ${EXTRA_CXXFLAGS}" >> config.mak
+echo "EXTRA_LDFLAGS= ${EXTRA_LDFLAGS}" >> config.mak
 export RING_EXTRA_CFLAGS="${EXTRA_CFLAGS}"
 export RING_EXTRA_CXXFLAGS="${EXTRA_CXXFLAGS}"
-export RING_EXTRA_LDFLAGS="${EXTRA_LDFLAGS} -L${SYSROOT}/usr/${LIBDIR}"
+export RING_EXTRA_LDFLAGS="${EXTRA_LDFLAGS}"
 
 make list
 make fetch
@@ -221,6 +210,9 @@ if [ ! -f config.h ]; then
     ./autogen.sh
     cd "${DAEMON_DIR}/build-android-${TARGET_TUPLE}"
     echo "Configuring with ${OPTS}"
+    CFLAGS="${EXTRA_CFLAGS}" \
+    CXXFLAGS="${EXTRA_CXXFLAGS}" \
+    LDFLAGS="${EXTRA_LDFLAGS}" \
     ${ANDROID_TOPLEVEL_DIR}/configure.sh ${OPTS}
 fi
 
@@ -253,14 +245,13 @@ STATIC_LIBS_ALL="-llog -lOpenSLES -landroid \
                 -lpjlib-util-${PJ_TARGET_TUPLE} \
                 -lpj-${PJ_TARGET_TUPLE} \
                 -lupnp -lixml -lthreadutil \
-                -lsamplerate \
                 -lsecp256k1 \
                 -lgnutls -lnettle -lhogweed -lgmp \
-                -lrestbed \
-                -lavformat -lavdevice -lavcodec -lavfilter -lavutil \
-                -lpcre -lsndfile -lyaml-cpp -ljsoncpp \
-                -luuid -lz -lswscale \
-                -lvpx -lx264 -lopus -lspeex -lvorbis -lvorbisenc -logg -lFLAC \
+                -lrestbed -lssl -lcrypto \
+                -lavformat -lavdevice -lavfilter -lavcodec -lswresample -lswscale -lavutil \
+                -lpcre -lyaml-cpp -ljsoncpp \
+                -luuid -lz \
+                -lvpx -lopus -lspeex \
                 -largon2 \
                 -liconv"
 
@@ -282,6 +273,5 @@ ${NDK_TOOLCHAIN_PATH}/clang++ \
                 -I${RING_SRC_DIR}/src \
                 -L${RING_SRC_DIR}/contrib/${TARGET_TUPLE}/lib \
                 ${STATIC_LIBS_ALL} \
-                ${STRIP_ARG} --std=c++11 \
+                ${STRIP_ARG} --std=c++14 -O3 -fPIC \
                 -o ${LIBRING_JNI_DIR}/libring.so
-
