@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2016 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2018 Savoir-faire Linux Inc.
  *
  *  Author: Romain Bertozzi <romain.bertozzi@savoirfairelinux.com>
  *
@@ -17,14 +17,12 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-
 package cx.ring.client;
 
-import android.app.Fragment;
-
 import com.google.zxing.integration.android.IntentIntegrator;
 import com.journeyapps.barcodescanner.CaptureActivity;
 
+import androidx.fragment.app.Fragment;
 import cx.ring.R;
 
 public class QRCodeScannerActivity extends CaptureActivity {
@@ -36,7 +34,7 @@ public class QRCodeScannerActivity extends CaptureActivity {
      */
     public static void startQRCodeScanWithFragmentReceiver(Fragment receiver) {
         if (null != receiver) {
-            IntentIntegrator integrator = IntentIntegrator.forFragment(receiver);
+            IntentIntegrator integrator = IntentIntegrator.forSupportFragment(receiver);
             configureIntentIntegrator(integrator,
                     receiver.getString(R.string.scan_qr_account_message));
         }
@@ -54,7 +52,7 @@ public class QRCodeScannerActivity extends CaptureActivity {
             return;
         }
         intentIntegrator.setPrompt(promptString);
-        intentIntegrator.setDesiredBarcodeFormats(IntentIntegrator.QR_CODE_TYPES);
+        intentIntegrator.setDesiredBarcodeFormats(IntentIntegrator.QR_CODE);
         intentIntegrator.setCaptureActivity(QRCodeScannerActivity.class);
         intentIntegrator.setBarcodeImageEnabled(true);
         intentIntegrator.setOrientationLocked(false);
