@@ -2,6 +2,7 @@
  *  Copyright (C) 2004-2018 Savoir-faire Linux Inc.
  *
  *  Author: Hadrien De Sousa <hadrien.desousa@savoirfairelinux.com>
+ *          Adrien Béraud <adrien.beraud@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,6 +20,7 @@
  */
 package cx.ring.fragments;
 
+import android.app.Activity;
 import android.app.PendingIntent;
 import android.app.PictureInPictureParams;
 import android.app.RemoteAction;
@@ -26,62 +28,66 @@ import android.content.Context;
 import android.content.Intent;
 import android.content.pm.ActivityInfo;
 import android.content.res.Configuration;
+import android.graphics.Matrix;
 import android.graphics.PixelFormat;
 import android.graphics.Rect;
-import android.graphics.drawable.Drawable;
+import android.graphics.RectF;
+import android.graphics.SurfaceTexture;
 import android.graphics.drawable.Icon;
-import android.hardware.display.DisplayManager;
 import android.os.Build;
 import android.os.Bundle;
 import android.os.PowerManager;
-import android.support.annotation.NonNull;
-import android.support.annotation.Nullable;
-import android.util.DisplayMetrics;
+
+import androidx.annotation.NonNull;
+import androidx.annotation.Nullable;
+
+import android.text.Editable;
+import android.text.TextWatcher;
 import android.util.Rational;
+import android.view.LayoutInflater;
 import android.view.Menu;
 import android.view.MenuInflater;
 import android.view.MenuItem;
+import android.view.Surface;
 import android.view.SurfaceHolder;
-import android.view.SurfaceView;
+import android.view.TextureView;
 import android.view.View;
 import android.view.ViewGroup;
 import android.view.inputmethod.InputMethodManager;
-import android.widget.EditText;
-import android.widget.ImageView;
 import android.widget.RelativeLayout;
-import android.widget.TextView;
 
-import com.bumptech.glide.Glide;
-import com.bumptech.glide.request.RequestOptions;
-import com.rodolfonavalon.shaperipplelibrary.ShapeRipple;
 import com.rodolfonavalon.shaperipplelibrary.model.Circle;
 
 import java.util.ArrayList;
 import java.util.Locale;
 import java.util.Random;
 
-import butterknife.BindView;
-import butterknife.OnClick;
+import androidx.appcompat.app.ActionBar;
+import androidx.appcompat.app.AppCompatActivity;
+import androidx.databinding.DataBindingUtil;
 import cx.ring.R;
+import cx.ring.application.RingApplication;
 import cx.ring.call.CallPresenter;
 import cx.ring.call.CallView;
+import cx.ring.client.CallActivity;
 import cx.ring.client.ConversationActivity;
 import cx.ring.client.HomeActivity;
-import cx.ring.contacts.AvatarFactory;
+import cx.ring.databinding.FragCallBinding;
 import cx.ring.dependencyinjection.RingInjectionComponent;
 import cx.ring.model.CallContact;
 import cx.ring.model.SipCall;
-import cx.ring.mvp.BaseFragment;
+import cx.ring.mvp.BaseSupportFragment;
 import cx.ring.service.DRingService;
-import cx.ring.services.HardwareServiceImpl;
 import cx.ring.services.NotificationService;
 import cx.ring.utils.ActionHelper;
 import cx.ring.utils.DeviceUtils;
 import cx.ring.utils.KeyboardVisibilityManager;
 import cx.ring.utils.Log;
 import cx.ring.utils.MediaButtonsHelper;
+import cx.ring.views.AvatarDrawable;
+import io.reactivex.disposables.CompositeDisposable;
 
-public class CallFragment extends BaseFragment<CallPresenter> implements CallView, MediaButtonsHelper.MediaButtonsHelperCallback {
+public class CallFragment extends BaseSupportFragment<CallPresenter> implements CallView, MediaButtonsHelper.MediaButtonsHelperCallback {
 
     public static final String TAG = CallFragment.class.getSimpleName();
 
@@ -93,50 +99,16 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
     public static final String KEY_CONF_ID = "confId";
     public static final String KEY_AUDIO_ONLY = "AUDIO_ONLY";
 
-    @BindView(R.id.contact_bubble_layout)
-    protected View contactBubbleLayout;
+    private FragCallBinding binding;
 
-    @BindView(R.id.contact_bubble)
-    protected ImageView contactBubbleView;
-
-    @BindView(R.id.contact_bubble_txt)
-    protected TextView contactBubbleTxt;
-
-    @BindView(R.id.contact_bubble_num_txt)
-    protected TextView contactBubbleNumTxt;
-
-    @BindView(R.id.call_accept_btn)
-    protected View acceptButton;
-
-    @BindView(R.id.call_refuse_btn)
-    protected View refuseButton;
-
-    @BindView(R.id.call_hangup_btn)
-    protected View hangupButton;
-
-    @BindView(R.id.call_status_txt)
-    protected TextView mCallStatusTxt;
-
-    @BindView(R.id.dialpad_edit_text)
-    protected EditText mNumeralDialEditText;
-
-    @BindView(R.id.shape_ripple)
-    protected ShapeRipple shapeRipple = null;
-
-    @BindView(R.id.video_preview_surface)
-    protected SurfaceView mVideoSurface = null;
-
-    @BindView(R.id.camera_preview_surface)
-    protected SurfaceView mVideoPreview = null;
-
-    private MenuItem speakerPhoneBtn = null;
-    private MenuItem flipCameraBtn = null;
     private MenuItem dialPadBtn = null;
     private MenuItem changeScreenOrientationBtn = null;
-
+    private boolean restartVideo = false;
     private PowerManager.WakeLock mScreenWakeLock;
-    private DisplayManager.DisplayListener displayListener;
     private int mCurrentOrientation = Configuration.ORIENTATION_UNDEFINED;
+    private int mPreviewWidth = 720, mPreviewHeight = 1280;
+
+    private final CompositeDisposable mCompositeDisposable = new CompositeDisposable();
 
     public static CallFragment newInstance(@NonNull String action, @Nullable String accountID, @Nullable String contactRingId, boolean audioOnly) {
         Bundle bundle = new Bundle();
@@ -158,31 +130,31 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
         return countDownFragment;
     }
 
-    public static int callStateToHumanState(final int state) {
+    public static int callStateToHumanState(final SipCall.State state) {
         switch (state) {
-            case SipCall.State.SEARCHING:
+            case SEARCHING:
                 return R.string.call_human_state_searching;
-            case SipCall.State.CONNECTING:
+            case CONNECTING:
                 return R.string.call_human_state_connecting;
-            case SipCall.State.RINGING:
+            case RINGING:
                 return R.string.call_human_state_ringing;
-            case SipCall.State.CURRENT:
+            case CURRENT:
                 return R.string.call_human_state_current;
-            case SipCall.State.HUNGUP:
+            case HUNGUP:
                 return R.string.call_human_state_hungup;
-            case SipCall.State.BUSY:
+            case BUSY:
                 return R.string.call_human_state_busy;
-            case SipCall.State.FAILURE:
+            case FAILURE:
                 return R.string.call_human_state_failure;
-            case SipCall.State.HOLD:
+            case HOLD:
                 return R.string.call_human_state_hold;
-            case SipCall.State.UNHOLD:
+            case UNHOLD:
                 return R.string.call_human_state_unhold;
-            case SipCall.State.OVER:
+            case OVER:
                 return R.string.call_human_state_over;
-            case SipCall.State.NONE:
+            case NONE:
             default:
-                return R.string.call_human_state_none;
+                return 0;
         }
     }
 
@@ -213,13 +185,13 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
         }
         if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
             PictureInPictureParams.Builder paramBuilder = new PictureInPictureParams.Builder();
-            if (mVideoSurface.getVisibility() == View.VISIBLE) {
+            if (binding.videoSurface.getVisibility() == View.VISIBLE) {
                 int[] l = new int[2];
-                mVideoSurface.getLocationInWindow(l);
+                binding.videoSurface.getLocationInWindow(l);
                 int x = l[0];
                 int y = l[1];
-                int w = mVideoSurface.getWidth();
-                int h = mVideoSurface.getHeight();
+                int w = binding.videoSurface.getWidth();
+                int h = binding.videoSurface.getHeight();
                 Rect videoBounds = new Rect(x, y, x + w, y + h);
                 paramBuilder.setAspectRatio(new Rational(w, h));
                 paramBuilder.setSourceRectHint(videoBounds);
@@ -250,6 +222,54 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
         component.inject(this);
     }
 
+    @Override
+    public void onStart() {
+        super.onStart();
+        if (restartVideo) {
+            displayVideoSurface(true);
+            restartVideo = false;
+        }
+    }
+
+    @Override
+    public void onStop() {
+        super.onStop();
+        if (binding.videoSurface.getVisibility() == View.VISIBLE) {
+            restartVideo = true;
+        }
+    }
+
+    @Nullable
+    @Override
+    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, Bundle savedInstanceState) {
+        injectFragment(((RingApplication) getActivity().getApplication()).getRingInjectionComponent());
+        binding = DataBindingUtil.inflate(inflater, R.layout.frag_call, container, false);
+        binding.setPresenter(this);
+        return binding.getRoot();
+    }
+
+    private TextureView.SurfaceTextureListener listener = new TextureView.SurfaceTextureListener() {
+        @Override
+        public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {
+            configureTransform(width, height);
+            presenter.previewVideoSurfaceCreated(binding.previewSurface);
+        }
+
+        @Override
+        public void onSurfaceTextureSizeChanged(SurfaceTexture surface, int width, int height) {
+            configureTransform(width, height);
+        }
+
+        @Override
+        public boolean onSurfaceTextureDestroyed(SurfaceTexture surface) {
+            presenter.previewVideoSurfaceDestroyed();
+            return true;
+        }
+
+        @Override
+        public void onSurfaceTextureUpdated(SurfaceTexture surface) {}
+    };
+
     @Override
     public void onViewCreated(View view, Bundle savedInstanceState) {
         setHasOptionsMenu(true);
@@ -263,23 +283,8 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
             mScreenWakeLock.acquire();
         }
 
-        displayListener = new DisplayManager.DisplayListener() {
-            @Override
-            public void onDisplayAdded(int displayId) {
-            }
-
-            @Override
-            public void onDisplayRemoved(int displayId) {
-            }
-
-            @Override
-            public void onDisplayChanged(int displayId) {
-                getActivity().runOnUiThread(() -> presenter.displayChanged());
-            }
-        };
-
-        mVideoSurface.getHolder().setFormat(PixelFormat.RGBA_8888);
-        mVideoSurface.getHolder().addCallback(new SurfaceHolder.Callback() {
+        binding.videoSurface.getHolder().setFormat(PixelFormat.RGBA_8888);
+        binding.videoSurface.getHolder().addCallback(new SurfaceHolder.Callback() {
             @Override
             public void surfaceCreated(SurfaceHolder holder) {
                 presenter.videoSurfaceCreated(holder);
@@ -295,43 +300,33 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
                 presenter.videoSurfaceDestroyed();
             }
         });
-        view.addOnLayoutChangeListener((parent, left, top, right, bottom, oldLeft, oldTop, oldRight, oldBottom) -> presenter.layoutChanged());
         view.setOnSystemUiVisibilityChangeListener(visibility -> {
             boolean ui = (visibility & (View.SYSTEM_UI_FLAG_HIDE_NAVIGATION | View.SYSTEM_UI_FLAG_FULLSCREEN)) == 0;
             presenter.uiVisibilityChanged(ui);
         });
 
-        mVideoPreview.getHolder().setFormat(PixelFormat.RGBA_8888);
-        mVideoPreview.getHolder().addCallback(new SurfaceHolder.Callback() {
+        binding.shapeRipple.setRippleShape(new Circle());
+        binding.callSpeakerBtn.setChecked(presenter.isSpeakerphoneOn());
+        binding.previewSurface.setSurfaceTextureListener(listener);
+
+        binding.dialpadEditText.addTextChangedListener(new TextWatcher() {
             @Override
-            public void surfaceCreated(SurfaceHolder holder) {
-                presenter.previewVideoSurfaceCreated(holder);
+            public void beforeTextChanged(CharSequence s, int start, int count, int after) {}
+
+            @Override
+            public void onTextChanged(CharSequence s, int start, int before, int count) {
+                presenter.sendDtmf(s.subSequence(start, start + count));
             }
 
             @Override
-            public void surfaceChanged(SurfaceHolder holder, int format, int width, int height) {
-
-            }
-
-            @Override
-            public void surfaceDestroyed(SurfaceHolder holder) {
-                presenter.previewVideoSurfaceDestroyed();
-            }
+            public void afterTextChanged(Editable s) {}
         });
-        mVideoPreview.setZOrderMediaOverlay(true);
-
-        shapeRipple.setRippleShape(new Circle());
     }
 
     @Override
-    public void onStop() {
-        super.onStop();
-
-        DisplayManager displayManager = (DisplayManager) getActivity().getSystemService(Context.DISPLAY_SERVICE);
-        if (displayManager != null) {
-            displayManager.unregisterDisplayListener(displayListener);
-        }
-
+    public void onDestroyView() {
+        super.onDestroyView();
+        mCompositeDisposable.clear();
         if (mScreenWakeLock != null && mScreenWakeLock.isHeld()) {
             mScreenWakeLock.release();
         }
@@ -356,8 +351,6 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
     public void onCreateOptionsMenu(Menu m, MenuInflater inf) {
         super.onCreateOptionsMenu(m, inf);
         inf.inflate(R.menu.ac_call, m);
-        speakerPhoneBtn = m.findItem(R.id.menuitem_speaker);
-        flipCameraBtn = m.findItem(R.id.menuitem_camera_flip);
         dialPadBtn = m.findItem(R.id.menuitem_dialpad);
         changeScreenOrientationBtn = m.findItem(R.id.menuitem_change_screen_orientation);
     }
@@ -376,13 +369,6 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
             case R.id.menuitem_chat:
                 presenter.chatClick();
                 break;
-            case R.id.menuitem_speaker:
-                presenter.speakerClick();
-                getActivity().invalidateOptionsMenu();
-                break;
-            case R.id.menuitem_camera_flip:
-                presenter.switchVideoInputClick();
-                break;
             case R.id.menuitem_dialpad:
                 presenter.dialpadClick();
                 break;
@@ -393,9 +379,12 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
         return true;
     }
 
-
     @Override
-    public void onPictureInPictureModeChanged(boolean isInPictureInPictureMode, Configuration newConfig) {
+    public void onPictureInPictureModeChanged(boolean isInPictureInPictureMode) {
+        if (isInPictureInPictureMode)
+            ((CallActivity) getActivity()).getSupportActionBar().hide();
+        else
+            ((CallActivity) getActivity()).getSupportActionBar().show();
         presenter.pipModeChanged(isInPictureInPictureMode);
     }
 
@@ -406,42 +395,41 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
 
     @Override
     public void displayContactBubble(final boolean display) {
-        getActivity().runOnUiThread(() -> contactBubbleLayout.setVisibility(display ? View.VISIBLE : View.GONE));
+        binding.contactBubbleLayout.getHandler().post(() -> binding.contactBubbleLayout.setVisibility(display ? View.VISIBLE : View.GONE));
     }
 
     @Override
     public void displayVideoSurface(final boolean display) {
-        mVideoSurface.setVisibility(display ? View.VISIBLE : View.GONE);
-        mVideoPreview.setVisibility(display ? View.VISIBLE : View.GONE);
+        binding.videoSurface.setVisibility(display ? View.VISIBLE : View.GONE);
+        binding.previewContainer.setVisibility(display ? View.VISIBLE : View.GONE);
         updateMenu();
     }
 
     @Override
     public void displayPreviewSurface(final boolean display) {
         if (display) {
-            mVideoPreview.setZOrderMediaOverlay(true);
-            mVideoSurface.setZOrderMediaOverlay(false);
+            binding.videoSurface.setZOrderOnTop(false);
+            binding.videoSurface.setZOrderMediaOverlay(false);
         } else {
-            mVideoPreview.setZOrderMediaOverlay(false);
-            mVideoSurface.setZOrderMediaOverlay(true);
+            binding.videoSurface.setZOrderMediaOverlay(true);
+            binding.videoSurface.setZOrderOnTop(true);
         }
     }
 
     @Override
     public void displayHangupButton(boolean display) {
-        hangupButton.setVisibility(display ? View.VISIBLE : View.GONE);
+        binding.callControlGroup.setVisibility(display ? View.VISIBLE : View.GONE);
+        binding.callHangupBtn.setVisibility(display ? View.VISIBLE : View.GONE);
     }
 
     @Override
     public void displayDialPadKeyboard() {
-        KeyboardVisibilityManager.showKeyboard(getActivity(),
-                mNumeralDialEditText,
-                InputMethodManager.SHOW_IMPLICIT);
+        KeyboardVisibilityManager.showKeyboard(getActivity(), binding.dialpadEditText, InputMethodManager.SHOW_FORCED);
     }
 
     @Override
     public void switchCameraIcon(boolean isFront) {
-        flipCameraBtn.setIcon(isFront ? R.drawable.ic_camera_front_white : R.drawable.ic_camera_rear_white);
+        binding.callCameraFlipBtn.setImageResource(isFront ? R.drawable.ic_camera_front_white : R.drawable.ic_camera_rear_white);
     }
 
     @Override
@@ -460,7 +448,8 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
 
     @Override
     public void updateTime(final long duration) {
-        getActivity().runOnUiThread(() -> mCallStatusTxt.setText(String.format(Locale.getDefault(), "%d:%02d:%02d", duration / 3600, duration % 3600 / 60, duration % 60)));
+        if (binding.callStatusTxt != null)
+            binding.callStatusTxt.setText(String.format(Locale.getDefault(), "%d:%02d:%02d", duration / 3600, duration % 3600 / 60, duration % 60));
     }
 
     @Override
@@ -469,92 +458,96 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
         String displayName = contact.getDisplayName();
 
         String ringId = contact.getIds().get(0);
-        Drawable contactPicture = AvatarFactory.getAvatar(
-                getActivity(),
-                contact.getPhoto(),
-                username,
-                ringId);
-
         Log.d(TAG, "updateContactBubble: contact=" + contact + " username=" + username + ", ringId=" + ringId);
 
         boolean hasProfileName = displayName != null && !displayName.contentEquals(username);
-        if (hasProfileName) {
-            contactBubbleNumTxt.setVisibility(View.VISIBLE);
-            contactBubbleTxt.setText(displayName);
-            contactBubbleNumTxt.setText(username);
-        } else {
-            contactBubbleNumTxt.setVisibility(View.GONE);
-            contactBubbleTxt.setText(username);
+
+        AppCompatActivity activity = (AppCompatActivity) getActivity();
+        if (activity != null) {
+            ActionBar ab = activity.getSupportActionBar();
+            if (ab != null) {
+                if (hasProfileName) {
+                    ab.setTitle(displayName);
+                    ab.setSubtitle(username);
+                } else {
+                    ab.setTitle(username);
+                    ab.setSubtitle(null);
+                }
+                ab.setDisplayShowTitleEnabled(true);
+            }
         }
 
-        Glide.with(getActivity())
-                .load(contactPicture)
-                .apply(AvatarFactory.getGlideOptions(true, false))
-                .into(contactBubbleView);
+        if (hasProfileName) {
+            binding.contactBubbleNumTxt.setVisibility(View.VISIBLE);
+            binding.contactBubbleTxt.setText(displayName);
+            binding.contactBubbleNumTxt.setText(username);
+        } else {
+            binding.contactBubbleNumTxt.setVisibility(View.GONE);
+            binding.contactBubbleTxt.setText(username);
+        }
+
+        binding.contactBubble.setImageDrawable(new AvatarDrawable(getActivity(), contact));
     }
 
     @Override
-    public void updateCallStatus(final int callState) {
-        getActivity().runOnUiThread(() -> {
-            switch (callState) {
-                case SipCall.State.NONE:
-                    mCallStatusTxt.setText("");
-                    break;
-                default:
-                    mCallStatusTxt.setText(callStateToHumanState(callState));
-                    break;
-            }
-        });
+    public void updateCallStatus(final SipCall.State callState) {
+        switch (callState) {
+            case NONE:
+                binding.callStatusTxt.setText("");
+                break;
+            default:
+                binding.callStatusTxt.setText(callStateToHumanState(callState));
+                break;
+        }
     }
 
     @Override
     public void initMenu(boolean isSpeakerOn, boolean hasContact, boolean displayFlip, boolean canDial, boolean onGoingCall) {
-        if (speakerPhoneBtn != null) {
-            speakerPhoneBtn.setVisible(onGoingCall);
-            if (speakerPhoneBtn.getIcon() != null) {
-                speakerPhoneBtn.getIcon().setAlpha(isSpeakerOn ? 255 : 128);
-            }
-            speakerPhoneBtn.setChecked(isSpeakerOn);
-        }
-        if (flipCameraBtn != null) {
-            flipCameraBtn.setVisible(displayFlip);
+        if (binding.callCameraFlipBtn != null) {
+            binding.callCameraFlipBtn.setVisibility(displayFlip ? View.VISIBLE : View.GONE);
         }
         if (dialPadBtn != null) {
             dialPadBtn.setVisible(canDial);
         }
         if (changeScreenOrientationBtn != null) {
-            changeScreenOrientationBtn.setVisible(mVideoSurface.getVisibility() == View.VISIBLE);
+            changeScreenOrientationBtn.setVisible(binding.videoSurface.getVisibility() == View.VISIBLE);
         }
     }
 
     @Override
-    public void initNormalStateDisplay(final boolean audioOnly) {
-        shapeRipple.stopRipple();
+    public void initNormalStateDisplay(final boolean audioOnly, boolean isSpeakerphoneOn) {
+        binding.shapeRipple.stopRipple();
 
-        acceptButton.setVisibility(View.GONE);
-        refuseButton.setVisibility(View.GONE);
-        hangupButton.setVisibility(View.VISIBLE);
+        binding.callAcceptBtn.setVisibility(View.GONE);
+        binding.callRefuseBtn.setVisibility(View.GONE);
+        binding.callControlGroup.setVisibility(View.VISIBLE);
+        binding.callHangupBtn.setVisibility(View.VISIBLE);
 
-        contactBubbleLayout.setVisibility(audioOnly ? View.VISIBLE : View.INVISIBLE);
+        binding.contactBubbleLayout.setVisibility(audioOnly ? View.VISIBLE : View.GONE);
+        binding.callSpeakerBtn.setChecked(isSpeakerphoneOn);
 
         getActivity().invalidateOptionsMenu();
     }
 
     @Override
     public void initIncomingCallDisplay() {
-        acceptButton.setVisibility(View.VISIBLE);
-        refuseButton.setVisibility(View.VISIBLE);
-        hangupButton.setVisibility(View.GONE);
+        binding.callAcceptBtn.setVisibility(View.VISIBLE);
+        binding.callRefuseBtn.setVisibility(View.VISIBLE);
+        binding.callControlGroup.setVisibility(View.GONE);
+        binding.callHangupBtn.setVisibility(View.GONE);
 
+        binding.contactBubbleLayout.setVisibility(View.VISIBLE);
         getActivity().invalidateOptionsMenu();
     }
 
     @Override
     public void initOutGoingCallDisplay() {
-        acceptButton.setVisibility(View.GONE);
-        refuseButton.setVisibility(View.VISIBLE);
-        hangupButton.setVisibility(View.GONE);
+        binding.callAcceptBtn.setVisibility(View.GONE);
+        binding.callRefuseBtn.setVisibility(View.VISIBLE);
+        binding.callControlGroup.setVisibility(View.GONE);
+        binding.callHangupBtn.setVisibility(View.GONE);
 
+        binding.contactBubbleLayout.setVisibility(View.VISIBLE);
         getActivity().invalidateOptionsMenu();
     }
 
@@ -567,7 +560,7 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
         double videoRatio = videoWidth / (double) videoHeight;
         double screenRatio = getView().getWidth() / (double) getView().getHeight();
 
-        RelativeLayout.LayoutParams params = (RelativeLayout.LayoutParams) mVideoSurface.getLayoutParams();
+        RelativeLayout.LayoutParams params = (RelativeLayout.LayoutParams) binding.videoSurface.getLayoutParams();
         int oldW = params.width;
         int oldH = params.height;
         if (videoRatio >= screenRatio) {
@@ -579,32 +572,41 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
         }
 
         if (oldW != params.width || oldH != params.height) {
-            mVideoSurface.setLayoutParams(params);
+            binding.videoSurface.setLayoutParams(params);
         }
 
-        final int mPreviewWidth;
-        final int mPreviewHeight;
+        if (previewWidth == -1 && previewHeight == -1)
+            return;
+        mPreviewWidth = previewWidth;
+        mPreviewHeight = previewHeight;
+        Log.w(TAG, "resetVideoSize preview: " + previewWidth + "x" + previewHeight);
+    }
 
-        if (mCurrentOrientation == Configuration.ORIENTATION_PORTRAIT) {
-            mPreviewWidth = HardwareServiceImpl.VIDEO_HEIGHT;
-            mPreviewHeight = HardwareServiceImpl.VIDEO_WIDTH;
-        } else {
-            mPreviewWidth = HardwareServiceImpl.VIDEO_WIDTH;
-            mPreviewHeight = HardwareServiceImpl.VIDEO_HEIGHT;
+    private void configureTransform(int viewWidth, int viewHeight) {
+        Activity activity = getActivity();
+        if (null == binding.previewSurface || null == activity) {
+            return;
         }
-
-        DisplayMetrics metrics = getResources().getDisplayMetrics();
-        RelativeLayout.LayoutParams paramsPreview = (RelativeLayout.LayoutParams) mVideoPreview.getLayoutParams();
-        oldW = paramsPreview.width;
-        oldH = paramsPreview.height;
-        double previewMaxDim = Math.max(mPreviewWidth, mPreviewHeight);
-        double previewRatio = metrics.density * 160. / previewMaxDim;
-        paramsPreview.width = (int) (mPreviewWidth * previewRatio);
-        paramsPreview.height = (int) (mPreviewHeight * previewRatio);
-
-        if (oldW != paramsPreview.width || oldH != paramsPreview.height) {
-            mVideoPreview.setLayoutParams(paramsPreview);
+        int rotation = activity.getWindowManager().getDefaultDisplay().getRotation();
+        boolean rot = Surface.ROTATION_90 == rotation || Surface.ROTATION_270 == rotation;
+        Log.w(TAG, "configureTransform " + viewWidth + "x" + viewHeight + " rot=" + rot + " mPreviewWidth=" + mPreviewWidth + " mPreviewHeight=" + mPreviewHeight);
+        Matrix matrix = new Matrix();
+        RectF viewRect = new RectF(0, 0, viewWidth, viewHeight);
+        float centerX = viewRect.centerX();
+        float centerY = viewRect.centerY();
+        if (rot) {
+            RectF bufferRect = new RectF(0, 0, mPreviewHeight, mPreviewWidth);
+            bufferRect.offset(centerX - bufferRect.centerX(), centerY - bufferRect.centerY());
+            matrix.setRectToRect(viewRect, bufferRect, Matrix.ScaleToFit.FILL);
+            float scale = Math.max(
+                    (float) viewHeight / mPreviewHeight,
+                    (float) viewWidth / mPreviewWidth);
+            matrix.postScale(scale, scale, centerX, centerY);
+            matrix.postRotate(90 * (rotation - 2), centerX, centerY);
+        } else if (Surface.ROTATION_180 == rotation) {
+            matrix.postRotate(180, centerX, centerY);
         }
+        binding.previewSurface.setTransform(matrix);
     }
 
     @Override
@@ -636,21 +638,30 @@ public class CallFragment extends BaseFragment<CallPresenter> implements CallVie
         getActivity().finish();
     }
 
-    @OnClick({R.id.call_hangup_btn})
+    public void speakerClicked() {
+        presenter.speakerClick(binding.callSpeakerBtn.isChecked());
+    }
+
+    public void micClicked() {
+        presenter.muteMicrophoneToggled(binding.callMicBtn.isChecked());
+    }
+
     public void hangUpClicked() {
         presenter.hangupCall();
     }
 
-    @OnClick(R.id.call_refuse_btn)
     public void refuseClicked() {
         presenter.refuseCall();
     }
 
-    @OnClick(R.id.call_accept_btn)
     public void acceptClicked() {
         presenter.acceptCall();
     }
 
+    public void cameraFlip() {
+        presenter.switchVideoInputClick();
+    }
+
     @Override
     public void positiveMediaButtonClicked() {
         presenter.positiveButtonClicked();
