@@ -28,24 +28,23 @@ import android.app.PendingIntent;
 import android.content.Context;
 import android.content.Intent;
 import android.graphics.Bitmap;
-import android.graphics.BitmapFactory;
-import android.graphics.drawable.Drawable;
+import android.graphics.drawable.BitmapDrawable;
 import android.media.AudioAttributes;
 import android.media.RingtoneManager;
 import android.os.Build;
 import android.os.Bundle;
-import android.support.annotation.RequiresApi;
-import android.support.v4.app.NotificationCompat;
-import android.support.v4.app.NotificationManagerCompat;
-import android.support.v4.content.res.ResourcesCompat;
-import android.text.Html;
-import android.text.Spanned;
-import android.text.format.DateUtils;
+import androidx.annotation.RequiresApi;
+import androidx.core.app.NotificationCompat;
+import androidx.core.app.NotificationManagerCompat;
+import androidx.core.app.RemoteInput;
+import androidx.core.content.res.ResourcesCompat;
+
 import android.util.SparseArray;
 
-import java.util.ArrayList;
+import com.bumptech.glide.Glide;
+
+import java.io.File;
 import java.util.Collection;
-import java.util.List;
 import java.util.Random;
 import java.util.Set;
 import java.util.TreeMap;
@@ -65,29 +64,27 @@ import cx.ring.model.DataTransfer;
 import cx.ring.model.DataTransferEventCode;
 import cx.ring.model.SipCall;
 import cx.ring.model.TextMessage;
-import cx.ring.model.TrustRequest;
 import cx.ring.model.Uri;
 import cx.ring.service.DRingService;
-import cx.ring.utils.BitmapUtils;
 import cx.ring.utils.FileUtils;
 import cx.ring.utils.Log;
 import cx.ring.utils.ResourceMapper;
-import ezvcard.VCard;
-import ezvcard.property.Photo;
-import io.reactivex.disposables.CompositeDisposable;
 
-public class NotificationServiceImpl extends NotificationService {
+public class NotificationServiceImpl implements NotificationService {
 
     private static final String TAG = NotificationServiceImpl.class.getSimpleName();
 
     private static final String NOTIF_MSG = "MESSAGE";
     private static final String NOTIF_TRUST_REQUEST = "TRUST REQUEST";
     private static final String NOTIF_FILE_TRANSFER = "FILE_TRANSFER";
+    private static final String NOTIF_MISSED_CALL = "MISSED_CALL";
 
     private static final String NOTIF_CHANNEL_CALL = "call";
     private static final String NOTIF_CHANNEL_MESSAGE = "messages";
     private static final String NOTIF_CHANNEL_REQUEST = "requests";
     private static final String NOTIF_CHANNEL_FILE_TRANSFER = "file_transfer";
+    private static final String NOTIF_CHANNEL_MISSED_CALL = "missed_call";
+    private static final String NOTIF_CHANNEL_SERVICE = "service";
 
     private final SparseArray<NotificationCompat.Builder> mNotificationBuilders = new SparseArray<>();
     @Inject
@@ -103,8 +100,6 @@ public class NotificationServiceImpl extends NotificationService {
     private NotificationManagerCompat notificationManager;
     private final Random random = new Random();
 
-    private final CompositeDisposable mDisposable = new CompositeDisposable();
-
     @SuppressLint("CheckResult")
     public void initHelper() {
         if (notificationManager == null) {
@@ -113,14 +108,6 @@ public class NotificationServiceImpl extends NotificationService {
         if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
             registerNotificationChannels();
         }
-        mAccountService.getCurrentAccountSubject()
-                .switchMap(a -> a
-                        .getPendingSubject()
-                        .map(p -> {
-                            showIncomingTrustRequestNotification(a);
-                            return a;
-                        }))
-                .subscribe();
     }
 
     @RequiresApi(api = Build.VERSION_CODES.O)
@@ -160,6 +147,21 @@ public class NotificationServiceImpl extends NotificationService {
         fileTransferChannel.setLockscreenVisibility(Notification.VISIBILITY_PUBLIC);
         fileTransferChannel.setSound(RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION), soundAttributes);
         notificationManager.createNotificationChannel(fileTransferChannel);
+
+        // Missed calls channel
+        NotificationChannel missedCallsChannel = new NotificationChannel(NOTIF_CHANNEL_MISSED_CALL, mContext.getString(R.string.notif_channel_missed_calls), NotificationManager.IMPORTANCE_DEFAULT);
+        missedCallsChannel.setLockscreenVisibility(Notification.VISIBILITY_PUBLIC);
+        missedCallsChannel.setSound(null, null);
+        notificationManager.createNotificationChannel(missedCallsChannel);
+
+        // Background service channel
+        NotificationChannel backgroundChannel = new NotificationChannel(NOTIF_CHANNEL_SERVICE, mContext.getString(R.string.notif_channel_background_service), NotificationManager.IMPORTANCE_LOW);
+        backgroundChannel.setDescription(mContext.getString(R.string.notif_channel_background_service_descr));
+        backgroundChannel.setLockscreenVisibility(Notification.VISIBILITY_SECRET);
+        backgroundChannel.enableLights(false);
+        backgroundChannel.enableVibration(false);
+        backgroundChannel.setShowBadge(false);
+        notificationManager.createNotificationChannel(backgroundChannel);
     }
 
     @Override
@@ -238,7 +240,18 @@ public class NotificationServiceImpl extends NotificationService {
     }
 
     @Override
-    public void showTextNotification(CallContact contact, Conversation conversation, TreeMap<Long, TextMessage> texts) {
+    public void showTextNotification(String accountId, Conversation conversation) {
+        TreeMap<Long, TextMessage> texts = conversation.getUnreadTextMessages();
+
+        CallContact contact = conversation.getContact();
+        if (texts.isEmpty() || conversation.isVisible()) {
+            cancelTextNotification(contact.getPrimaryUri());
+            return;
+        }
+        if (texts.lastEntry().getValue().isNotified()) {
+            return;
+        }
+
         Uri contactUri = contact.getPrimaryUri();
         if (texts.isEmpty()) {
             cancelTextNotification(contactUri);
@@ -249,12 +262,12 @@ public class NotificationServiceImpl extends NotificationService {
 
         Intent intentConversation = new Intent(DRingService.ACTION_CONV_ACCEPT)
                 .setClass(mContext, DRingService.class)
-                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, conversation.getLastAccountUsed())
+                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, accountId)
                 .putExtra(ConversationFragment.KEY_CONTACT_RING_ID, contactId);
 
         Intent intentDelete = new Intent(DRingService.ACTION_CONV_DISMISS)
                 .setClass(mContext, DRingService.class)
-                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, conversation.getLastAccountUsed())
+                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, accountId)
                 .putExtra(ConversationFragment.KEY_CONTACT_RING_ID, contactId);
 
         NotificationCompat.Builder messageNotificationBuilder = new NotificationCompat.Builder(mContext, NOTIF_CHANNEL_MESSAGE)
@@ -277,28 +290,40 @@ public class NotificationServiceImpl extends NotificationService {
             last.setNotified(true);
             messageNotificationBuilder.setStyle(null);
         } else {
-            ArrayList<Spanned> txts = new ArrayList<>(3);
-            int i = 0;
-            for (TextMessage textMessage : texts.descendingMap().values()) {
-                if (i == 5)
-                    break;
-                txts.add(0, Html.fromHtml("<b>" + DateUtils.formatDateTime(mContext, textMessage.getDate(), DateUtils.FORMAT_SHOW_TIME | DateUtils.FORMAT_ABBREV_ALL) + "</b> " + textMessage.getMessage()));
-                textMessage.setNotified(true);
-                i++;
+            NotificationCompat.MessagingStyle history = new NotificationCompat.MessagingStyle(contact.getDisplayName());
+            for (TextMessage textMessage : texts.values()) {
+                history.addMessage(new NotificationCompat.MessagingStyle.Message(
+                        textMessage.getMessage(),
+                        textMessage.getDate(),
+                        textMessage.isIncoming() ? contact.getDisplayName() : "You"));
             }
-            NotificationCompat.InboxStyle inboxStyle = new NotificationCompat.InboxStyle();
-            for (Spanned spanned : txts) {
-                inboxStyle.addLine(spanned);
-            }
-            messageNotificationBuilder.setStyle(inboxStyle);
+            messageNotificationBuilder.setStyle(history);
         }
 
+        CharSequence replyLabel = mContext.getText(R.string.notif_reply);
+        RemoteInput remoteInput = new RemoteInput.Builder(DRingService.KEY_TEXT_REPLY)
+                .setLabel(replyLabel)
+                .build();
+        Intent intentReply = new Intent(DRingService.ACTION_CONV_REPLY_INLINE)
+                .setClass(mContext, DRingService.class)
+                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, accountId)
+                .putExtra(ConversationFragment.KEY_CONTACT_RING_ID, contactId);
+        PendingIntent replyPendingIntent = PendingIntent.getService(mContext, random.nextInt(),
+                        intentReply,
+                        PendingIntent.FLAG_UPDATE_CURRENT);
+        NotificationCompat.Action action =
+                new NotificationCompat.Action.Builder(R.drawable.baseline_reply_black_24,
+                        replyLabel, replyPendingIntent)
+                        .addRemoteInput(remoteInput)
+                        .build();
+        messageNotificationBuilder.addAction(action);
+
         Intent intentRead = new Intent(DRingService.ACTION_CONV_READ)
                 .setClass(mContext, DRingService.class)
-                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, conversation.getLastAccountUsed())
+                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, accountId)
                 .putExtra(ConversationFragment.KEY_CONTACT_RING_ID, contactId);
-
         messageNotificationBuilder.addAction(0, mContext.getString(R.string.notif_mark_as_read), PendingIntent.getService(mContext, Long.valueOf(System.currentTimeMillis()).intValue(), intentRead, 0));
+
         int notificationId = getTextNotificationId(contactUri);
         notificationManager.notify(notificationId, messageNotificationBuilder.build());
         mNotificationBuilders.put(notificationId, messageNotificationBuilder);
@@ -307,24 +332,16 @@ public class NotificationServiceImpl extends NotificationService {
     @Override
     public void showIncomingTrustRequestNotification(final Account account) {
         int notificationId = getIncomingTrustNotificationId(account.getAccountID());
-        NotificationCompat.Builder messageNotificationBuilder = mNotificationBuilders.get(notificationId);
-
-        if (messageNotificationBuilder != null) {
-            notificationManager.cancel(notificationId);
-        } else {
-            messageNotificationBuilder = new NotificationCompat.Builder(mContext, NOTIF_CHANNEL_REQUEST);
-        }
-
+        NotificationCompat.Builder messageNotificationBuilder;
         Set<String> notifiedRequests = mPreferencesService.loadRequestsPreferences(account.getAccountID());
 
         Collection<Conversation> requests = account.getPending();
-        Log.w(TAG, "showIncomingTrustRequestNotification " + requests.size());
         if (requests.isEmpty()) {
             return;
         } else if (requests.size() == 1) {
             Conversation request = requests.iterator().next();
             CallContact contact = request.getContact();
-            String contactKey = contact.getKey();
+            String contactKey = contact.getPrimaryUri().getRawRingId();
             if (notifiedRequests.contains(contactKey)) {
                 return;
             }
@@ -354,17 +371,18 @@ public class NotificationServiceImpl extends NotificationService {
                                     PendingIntent.FLAG_ONE_SHOT));
 
 
-            List<Photo> photos = contact.vcard == null ? null : contact.vcard.getPhotos();
+            /*List<Photo> photos = contact.vcard == null ? null : contact.vcard.getPhotos();
             byte[] data = null;
             if (photos != null && !photos.isEmpty()) {
                 data = photos.get(0).getData();
-            }
-            setContactPicture(data, contact.getRingUsername(), contact.getPrimaryNumber(), messageNotificationBuilder);
+            }*/
+            setContactPicture(contact, messageNotificationBuilder);
         } else {
+            messageNotificationBuilder = new NotificationCompat.Builder(mContext, NOTIF_CHANNEL_REQUEST);
             boolean newRequest = false;
             for (Conversation request : requests) {
                 CallContact contact = request.getContact();
-                String contactKey = contact.getKey();
+                String contactKey = contact.getPrimaryUri().getRawRingId();
                 if (!notifiedRequests.contains(contactKey)) {
                     newRequest = true;
                     mPreferencesService.saveRequestPreferences(account.getAccountID(), contactKey);
@@ -409,9 +427,39 @@ public class NotificationServiceImpl extends NotificationService {
         }
         long dataTransferId = info.getDataTransferId();
         int notificationId = getFileTransferNotificationId(dataTransferId);
-        if (event == DataTransferEventCode.FINISHED) {
+
+        String contactUri = new Uri(info.getPeerId()).getRawUriString();
+        Intent intentConversation = new Intent(DRingService.ACTION_CONV_ACCEPT)
+                .setClass(mContext, DRingService.class)
+                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, mAccountService.getCurrentAccount().getAccountID())
+                .putExtra(ConversationFragment.KEY_CONTACT_RING_ID, contactUri);
+
+        if (event.isOver()) {
             notificationManager.cancel(notificationId);
             mNotificationBuilders.delete(notificationId);
+            if (!info.isOutgoing() && info.showPicture()) {
+                File path = mDeviceRuntimeService.getConversationPath(info.getPeerId(), info.getStoragePath());
+                Bitmap img;
+                try {
+                    BitmapDrawable d = (BitmapDrawable) Glide.with(mContext)
+                            .load(path)
+                            .submit()
+                            .get();
+                    img = d.getBitmap();
+                } catch (Exception e) {
+                    Log.w(TAG, "Can't load image for notification", e);
+                    return;
+                }
+                NotificationCompat.Builder notif = new NotificationCompat.Builder(mContext, NOTIF_CHANNEL_FILE_TRANSFER)
+                        .setContentTitle(mContext.getString(R.string.notif_incoming_picture, contact.getDisplayName()))
+                        .setSmallIcon(R.drawable.ic_ring_logo_white)
+                        .setContentIntent(PendingIntent.getService(mContext, random.nextInt(), intentConversation, 0))
+                        .setAutoCancel(true)
+                        .setStyle(new NotificationCompat.BigPictureStyle()
+                                .bigPicture(img));
+                setContactPicture(contact, notif);
+                notificationManager.notify(random.nextInt(), notif.build());
+            }
             return;
         }
         NotificationCompat.Builder messageNotificationBuilder = mNotificationBuilders.get(notificationId);
@@ -420,24 +468,13 @@ public class NotificationServiceImpl extends NotificationService {
         }
 
         boolean ongoing = event == DataTransferEventCode.CREATED || event == DataTransferEventCode.ONGOING;
-        boolean outgoing = info.isOutgoing();
-
-        String contactUri = new Uri(info.getPeerId()).getRawUriString();
-        Intent intentConversation = new Intent(DRingService.ACTION_CONV_ACCEPT)
-                .setClass(mContext, DRingService.class)
-                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, mAccountService.getCurrentAccount().getAccountID())
-                .putExtra(ConversationFragment.KEY_CONTACT_RING_ID, contactUri);
-
-        String titleMessage = mContext.getString(outgoing ? R.string.notif_outgoing_file_transfer_title : R.string.notif_incoming_file_transfer_title, contact.getDisplayName());
-        byte[] photo = contact.getPhoto();
-        Bitmap photo_bmp = photo == null ? null : BitmapFactory.decodeByteArray(photo, 0, photo.length);
+        String titleMessage = mContext.getString(info.isOutgoing() ? R.string.notif_outgoing_file_transfer_title : R.string.notif_incoming_file_transfer_title, contact.getDisplayName());
         messageNotificationBuilder.setContentTitle(titleMessage)
                 .setPriority(NotificationCompat.PRIORITY_DEFAULT)
                 .setVisibility(NotificationCompat.VISIBILITY_PUBLIC)
                 .setAutoCancel(false)
                 .setOngoing(ongoing)
                 .setSmallIcon(R.drawable.ic_ring_logo_white)
-                .setLargeIcon(photo_bmp)
                 .setCategory(NotificationCompat.CATEGORY_PROGRESS)
                 .setOnlyAlertOnce(true)
                 .setContentText(event == DataTransferEventCode.ONGOING ?
@@ -445,10 +482,10 @@ public class NotificationServiceImpl extends NotificationService {
                         info.getDisplayName() + ": " + ResourceMapper.getReadableFileTransferStatus(mContext, event))
                 .setContentIntent(PendingIntent.getService(mContext, random.nextInt(), intentConversation, 0))
                 .setColor(ResourcesCompat.getColor(mContext.getResources(), R.color.color_primary_dark, null));
+        setContactPicture(contact, messageNotificationBuilder);
         if (event.isOver()) {
             messageNotificationBuilder.setProgress(0, 0, false);
         } else if (ongoing) {
-            Log.w(TAG, "messageNotificationBuilder.setProgress " + info.getTotalSize() + " " + info.getBytesProgress());
             messageNotificationBuilder.setProgress((int)info.getTotalSize(), (int)info.getBytesProgress(), false);
         } else {
             messageNotificationBuilder.setProgress(0, 0, true);
@@ -487,6 +524,54 @@ public class NotificationServiceImpl extends NotificationService {
         notificationManager.notify(notificationId, messageNotificationBuilder.build());
     }
 
+    @Override
+    public void showMissedCallNotification(SipCall call) {
+        final int notificationId = call.getCallId().hashCode();
+        NotificationCompat.Builder messageNotificationBuilder = mNotificationBuilders.get(notificationId);
+        if (messageNotificationBuilder == null) {
+            messageNotificationBuilder = new NotificationCompat.Builder(mContext, NOTIF_CHANNEL_MISSED_CALL);
+        }
+
+        String contactUri = call.getNumberUri().getRawUriString();
+        Intent intentConversation = new Intent(DRingService.ACTION_CONV_ACCEPT)
+                .setClass(mContext, DRingService.class)
+                .putExtra(ConversationFragment.KEY_ACCOUNT_ID, mAccountService.getCurrentAccount().getAccountID())
+                .putExtra(ConversationFragment.KEY_CONTACT_RING_ID, contactUri);
+
+        messageNotificationBuilder.setContentTitle(mContext.getText(R.string.notif_missed_incoming_call))
+                .setPriority(NotificationCompat.PRIORITY_DEFAULT)
+                .setVisibility(NotificationCompat.VISIBILITY_PUBLIC)
+                .setSmallIcon(R.drawable.baseline_call_missed_white_24)
+                .setCategory(NotificationCompat.CATEGORY_CALL)
+                .setOnlyAlertOnce(true)
+                .setAutoCancel(true)
+                .setContentText(call.getContact().getDisplayName())
+                .setContentIntent(PendingIntent.getService(mContext, random.nextInt(), intentConversation, 0))
+                .setColor(ResourcesCompat.getColor(mContext.getResources(), R.color.color_primary_dark, null));
+
+        setContactPicture(call.getContact(), messageNotificationBuilder);
+        notificationManager.notify(notificationId, messageNotificationBuilder.build());
+    }
+
+    @Override
+    public Object getServiceNotification() {
+        Intent intentHome = new Intent(Intent.ACTION_VIEW)
+                .setClass(mContext, HomeActivity.class)
+                .setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
+        PendingIntent pendIntent = PendingIntent.getActivity(mContext, 0, intentHome, PendingIntent.FLAG_UPDATE_CURRENT);
+        NotificationCompat.Builder messageNotificationBuilder = new NotificationCompat.Builder(mContext, NotificationServiceImpl.NOTIF_CHANNEL_SERVICE);
+        messageNotificationBuilder
+                .setContentTitle(mContext.getText(R.string.app_name))
+                .setContentText(mContext.getText(R.string.notif_background_service))
+                .setSmallIcon(R.drawable.ic_ring_logo_white)
+                .setContentIntent(pendIntent)
+                .setVisibility(NotificationCompat.VISIBILITY_SECRET)
+                .setPriority(NotificationCompat.PRIORITY_MIN)
+                .setOngoing(true)
+                .setCategory(NotificationCompat.CATEGORY_SERVICE);
+        return messageNotificationBuilder.build();
+    }
+
     @Override
     public void cancelTextNotification(Uri contact) {
         if (contact == null) {
@@ -519,6 +604,13 @@ public class NotificationServiceImpl extends NotificationService {
         mNotificationBuilders.remove(notificationId);
     }
 
+    @Override
+    public void cancelFileNotification(long fileId) {
+        int nId = getFileTransferNotificationId(fileId);
+        notificationManager.cancel(nId);
+        mNotificationBuilders.remove(nId);
+    }
+
     @Override
     public void cancelAll() {
         notificationManager.cancelAll();
@@ -533,28 +625,12 @@ public class NotificationServiceImpl extends NotificationService {
         return (NOTIF_MSG + contact.toString()).hashCode();
     }
 
-    private int getFileTransferNotificationId(Long dataTransferId) {
+    private int getFileTransferNotificationId(long dataTransferId) {
         return (NOTIF_FILE_TRANSFER + dataTransferId).hashCode();
     }
 
     private void setContactPicture(CallContact contact, NotificationCompat.Builder messageNotificationBuilder) {
-        setContactPicture(contact.getPhoto(), contact.getUsername(),
-                contact.getPhones().get(0).getNumber().getHost(), messageNotificationBuilder);
+        int size = (int) (mContext.getResources().getDisplayMetrics().density * AvatarFactory.SIZE_NOTIF);
+        messageNotificationBuilder.setLargeIcon(AvatarFactory.getBitmapAvatar(mContext, contact, size).blockingGet());
     }
-
-    private void setContactPicture(byte[] photo, String username, String ringId, NotificationCompat.Builder messageNotificationBuilder) {
-        Drawable contactPicture = AvatarFactory.getAvatar(mContext, photo, username, ringId);
-
-        Bitmap contactBitmap = BitmapUtils.drawableToBitmap(contactPicture);
-        if (contactBitmap == null) {
-            Log.d(TAG, "showCallNotification: not able to generate contactBitmap");
-            return;
-        }
-        Bitmap circleBitmap = BitmapUtils.cropImageToCircle(contactBitmap);
-        if (circleBitmap == null) {
-            Log.d(TAG, "showCallNotification: not able to generate circleBitmap");
-            return;
-        }
-        messageNotificationBuilder.setLargeIcon(circleBitmap);
-    }
-}
\ No newline at end of file
+}
