@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2016 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2018 Savoir-faire Linux Inc.
  *
  *  Author: Thibault Wittemberg <thibault.wittemberg@savoirfairelinux.com>
  *
@@ -21,9 +21,13 @@ package cx.ring.mvp;
 
 import java.lang.ref.WeakReference;
 
+import io.reactivex.disposables.CompositeDisposable;
+
 public abstract class RootPresenter<T> {
 
-    public RootPresenter () {
+    protected CompositeDisposable mCompositeDisposable = new CompositeDisposable();
+
+    public RootPresenter() {
 
     }
 
@@ -39,6 +43,7 @@ public abstract class RootPresenter<T> {
         }
 
         mView = null;
+        mCompositeDisposable.dispose();
     }
 
     public T getView() {
@@ -49,8 +54,6 @@ public abstract class RootPresenter<T> {
         return null;
     }
 
-    public abstract void afterInjection ();
-
 }
 
 
