@@ -1,7 +1,8 @@
 /*
- *  Copyright (C) 2016 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2018 Savoir-faire Linux Inc.
  *
  *  Author: Thibault Wittemberg <thibault.wittemberg@savoirfairelinux.com>
+ *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,55 +20,46 @@
  */
 package cx.ring.settings;
 
-import java.util.Observable;
-import java.util.Observer;
-
 import javax.inject.Inject;
+import javax.inject.Named;
 
 import cx.ring.model.Settings;
 import cx.ring.mvp.GenericView;
 import cx.ring.mvp.RootPresenter;
 import cx.ring.services.HistoryService;
-import cx.ring.services.SettingsService;
+import cx.ring.services.PreferencesService;
+import io.reactivex.Scheduler;
 
-public class SettingsPresenter extends RootPresenter<GenericView<SettingsViewModel>> implements Observer {
+public class SettingsPresenter extends RootPresenter<GenericView<Settings>>  {
+
+    private final PreferencesService mPreferencesService;
+    private final HistoryService mHistoryService;
+    private final Scheduler mUiScheduler;
 
     @Inject
-    SettingsService mSettingsService;
-
-    @Inject
-    HistoryService mHistoryService;
+    public SettingsPresenter(PreferencesService preferencesService, HistoryService historyService, @Named("UiScheduler") Scheduler uiScheduler) {
+        mPreferencesService = preferencesService;
+        mHistoryService = historyService;
+        mUiScheduler = uiScheduler;
+    }
 
     @Override
-    public void afterInjection() {
-        // We observe the application settings changes
-        mSettingsService.addObserver(this);
-        // no need to observe the history changes
-        // only the smartlist should do so
+    public void bindView(GenericView<Settings> view) {
+        super.bindView(view);
+        mCompositeDisposable.add(mPreferencesService.getSettingsSubject()
+                .observeOn(mUiScheduler)
+                .subscribe(settings -> getView().showViewModel(settings)));
     }
 
     public void loadSettings() {
-        if (getView() == null) {
-            return;
-        }
-
-        // load the app settings
-        Settings settings = mSettingsService.loadSettings();
-
-        // let the view display the associated ViewModel
-        getView().showViewModel(new SettingsViewModel(settings));
+        mPreferencesService.getSettings();
     }
 
-    public void saveSettings (Settings settings) {
-        mSettingsService.saveSettings(settings);
+    public void saveSettings(Settings settings) {
+        mPreferencesService.setSettings(settings);
     }
 
     public void clearHistory() {
         mHistoryService.clearHistory();
     }
-
-    @Override
-    public void update(Observable observable, Object o) {
-        loadSettings();
-    }
 }
