@@ -23,6 +23,7 @@
 
 #import "LoadingWCDelegate.h"
 #import "AbstractLoadingWC.h"
+#import "LrcModelsProtocol.h"
 
 @protocol BackupAccountDelegate <LoadingWCDelegate>
 
@@ -32,41 +33,12 @@
 
 @end
 
-@interface BackupAccountWC : AbstractLoadingWC
-
-- (id)initWithDelegate:(id <LoadingWCDelegate>) del;
+@interface BackupAccountWC : AbstractLoadingWC <LrcModelsProtocol, NSPathControlDelegate, NSOpenSavePanelDelegate>
 
 /**
  * Allow the NSPathControl of this window to select files or not
  */
 @property (nonatomic) BOOL allowFileSelection;
-
-/**
- * password string contained in passwordField.
- * This is a KVO method to bind the text with the OK Button
- * if password.length is > 0, button is enabled, otherwise disabled
- */
-@property (retain) NSString* password;
-
-/**
- * Object uses to store account to exports
- */
-@property (assign) QStringList accounts;
-
-/**
- * passwordConfirmation string contained in passwordConfirmationField.
- */
-@property (retain) NSString* passwordConfirmation;
-
-/**
- * computed properties calculated by password string contained in
- * passwordField and passwordCOnfirmation string contained
- * inpasswordConfirmationField
- * This is a KVO method to bind the text with the OK Button
- * if password.length is > 0 AND passwordConfirmation.length > 0
- * AND password isEqualsToString passwordCOnfirmationbutton is enabled,
- * otherwise disabled
- */
-@property (readonly) BOOL validatePasswords;
+@property std::string selectedAccountID;
 
 @end
