@@ -24,7 +24,6 @@
 #include "media_encoder.h"
 #include "media_buffer.h"
 #include "media_io_handle.h"
-#include "media_recorder.h"
 
 #include "audio/audiobuffer.h"
 #include "string_utils.h"
@@ -50,15 +49,18 @@ MediaEncoder::MediaEncoder()
 
 MediaEncoder::~MediaEncoder()
 {
-    if (auto rec = recorder_.lock())
-        rec->stopRecording();
     if (outputCtx_) {
         if (outputCtx_->priv_data)
             av_write_trailer(outputCtx_);
 
         for (auto encoderCtx : encoders_)
-            if (encoderCtx)
+            if (encoderCtx) {
+#ifndef _MSC_VER
+                avcodec_free_context(&encoderCtx);
+#else
                 avcodec_close(encoderCtx);
+#endif
+            }
 
         avformat_free_context(outputCtx_);
     }
@@ -282,9 +284,11 @@ MediaEncoder::addStream(const SystemCodecInfo& systemCodecInfo, std::string para
         // allocate buffers for both scaled (pre-encoder) and encoded frames
         const int width = encoderCtx->width;
         const int height = encoderCtx->height;
-        const int format = libav_utils::ring_pixel_format((int)encoderCtx->pix_fmt);
+        const int format = encoderCtx->pix_fmt;
         scaledFrameBufferSize_ = videoFrameSize(format, width, height);
-        if (scaledFrameBufferSize_ <= AV_INPUT_BUFFER_MIN_SIZE)
+        if (scaledFrameBufferSize_ < 0)
+            throw MediaEncoderException(("Could not compute buffer size: " + libav_utils::getError(scaledFrameBufferSize_)).c_str());
+        else if (scaledFrameBufferSize_ <= AV_INPUT_BUFFER_MIN_SIZE)
             throw MediaEncoderException("buffer too small");
 
         scaledFrameBuffer_.reserve(scaledFrameBufferSize_);
@@ -341,15 +345,6 @@ MediaEncoder::startIO()
 #endif
 }
 
-// seq: frame number for video, sent samples audio
-// sampleFreq: fps for video, sample rate for audio
-// clock: stream time base (packetization interval times)
-int64_t
-getNextTimestamp(int64_t seq, rational<int64_t> sampleFreq, rational<int64_t> clock)
-{
-    return (seq / (sampleFreq * clock)).real<int64_t>();
-}
-
 #ifdef RING_VIDEO
 int
 MediaEncoder::encode(VideoFrame& input, bool is_keyframe,
@@ -358,13 +353,17 @@ MediaEncoder::encode(VideoFrame& input, bool is_keyframe,
     /* Prepare a frame suitable to our encoder frame format,
      * keeping also the input aspect ratio.
      */
-    yuv422_clear_to_black(scaledFrame_); // to fill blank space left by the "keep aspect"
+    libav_utils::fillWithBlack(scaledFrame_.pointer());
 
     scaler_.scale_with_aspect(input, scaledFrame_);
 
     auto frame = scaledFrame_.pointer();
     AVCodecContext* enc = encoders_[currentStreamIdx_];
-    frame->pts = getNextTimestamp(frame_number, enc->framerate, enc->time_base);
+    // ideally, time base is the inverse of framerate, but this may not always be the case
+    if (enc->framerate.num == enc->time_base.den && enc->framerate.den == enc->time_base.num)
+        frame->pts = frame_number;
+    else
+        frame->pts = (frame_number / (rational<int64_t>(enc->framerate) * rational<int64_t>(enc->time_base))).real<int64_t>();
 
     if (is_keyframe) {
         frame->pict_type = AV_PICTURE_TYPE_I;
@@ -378,91 +377,11 @@ MediaEncoder::encode(VideoFrame& input, bool is_keyframe,
 }
 #endif // RING_VIDEO
 
-int MediaEncoder::encode_audio(const AudioBuffer &buffer)
+int MediaEncoder::encodeAudio(AudioFrame& frame)
 {
-    const int needed_bytes = av_samples_get_buffer_size(nullptr, buffer.channels(),
-                                                        buffer.frames(),
-                                                        AV_SAMPLE_FMT_S16, 0);
-    if (needed_bytes < 0) {
-        RING_ERR("Couldn't calculate buffer size");
-        return -1;
-    }
-
-    std::vector<AudioSample> samples (needed_bytes / sizeof(AudioSample));
-    AudioSample* sample_data = samples.data();
-
-    AudioSample *offset_ptr = sample_data;
-    int nb_frames = buffer.frames();
-
-    AVCodecContext* encoderCtx = encoders_[currentStreamIdx_];
-
-    if (not is_muted) {
-        //only fill buffer with samples if not muted
-        buffer.interleave(sample_data);
-    } else {
-        //otherwise filll buffer with zero
-        buffer.fillWithZero(sample_data);
-    }
-    const auto layout = buffer.channels() == 2 ? AV_CH_LAYOUT_STEREO : AV_CH_LAYOUT_MONO;
-    const auto sample_rate = buffer.getSampleRate();
-
-    while (nb_frames > 0) {
-        AVFrame* frame = av_frame_alloc();
-        if (!frame)
-            return -1;
-
-        if (encoderCtx->frame_size)
-            frame->nb_samples = std::min<int>(nb_frames,
-                                              encoderCtx->frame_size);
-        else
-            frame->nb_samples = nb_frames;
-
-        frame->format = AV_SAMPLE_FMT_S16;
-        frame->channel_layout = layout;
-        frame->channels = buffer.channels();
-        frame->sample_rate = sample_rate;
-
-        frame->pts = getNextTimestamp(sent_samples, encoderCtx->sample_rate, encoderCtx->time_base);
-        sent_samples += frame->nb_samples;
-
-        const auto buffer_size = \
-            av_samples_get_buffer_size(nullptr, buffer.channels(),
-                                       frame->nb_samples, AV_SAMPLE_FMT_S16, 0);
-
-        int err = avcodec_fill_audio_frame(frame, buffer.channels(),
-                                           AV_SAMPLE_FMT_S16,
-                                           reinterpret_cast<const uint8_t *>(offset_ptr),
-                                           buffer_size, 0);
-        if (err < 0) {
-            RING_ERR() << "Failed to fill audio frame of size" << buffer_size << " with "
-                << frame->nb_samples << " samples: " << libav_utils::getError(err);
-            av_frame_free(&frame);
-            return -1;
-        }
-
-        nb_frames -= frame->nb_samples;
-        offset_ptr += frame->nb_samples * buffer.channels();
-
-        if (auto rec = recorder_.lock()) {
-            if (!recordingStarted_) {
-                auto ms = MediaStream("", encoders_[currentStreamIdx_], frame->pts);
-                if (rec->addStream(false, false, ms) >= 0) {
-                    recordingStarted_ = true;
-                } else {
-                    recorder_ = std::weak_ptr<MediaRecorder>();
-                }
-            }
-            if (recordingStarted_)
-                rec->recordData(frame, false, false);
-        } else {
-            recordingStarted_ = false;
-            recorder_ = std::weak_ptr<MediaRecorder>();
-        }
-
-        encode(frame, currentStreamIdx_);
-        av_frame_free(&frame);
-    }
-
+    frame.pointer()->pts = sent_samples;
+    sent_samples += frame.pointer()->nb_samples;
+    encode(frame.pointer(), currentStreamIdx_);
     return 0;
 }
 
@@ -719,15 +638,18 @@ MediaEncoder::getStreamCount() const
         return 0;
 }
 
-void
-MediaEncoder::initRecorder(std::shared_ptr<MediaRecorder>& rec)
+MediaStream
+MediaEncoder::getStream(const std::string& name, int streamIdx) const
 {
-    // recording will start once we can send an AVPacket to the recorder
-    recordingStarted_ = false;
-    recorder_ = rec;
-    if (auto r = recorder_.lock()) {
-        r->incrementStreams(1);
-    }
+    // if streamIdx is negative, use currentStreamIdx_
+    if (streamIdx < 0)
+        streamIdx = currentStreamIdx_;
+    // make sure streamIdx is valid
+    if (getStreamCount() <= 0 || streamIdx < 0 || encoders_.size() < (unsigned)(streamIdx + 1))
+        return {};
+    auto enc = encoders_[streamIdx];
+    // TODO set firstTimestamp
+    return MediaStream(name, enc);
 }
 
 } // namespace ring
