@@ -32,6 +32,7 @@
 #include "media_buffer.h"
 #include "media_codec.h"
 #include "media_device.h"
+#include "media_stream.h"
 
 #include <map>
 #include <memory>
@@ -75,7 +76,7 @@ public:
     int encode(VideoFrame &input, bool is_keyframe, int64_t frame_number);
 #endif // RING_VIDEO
 
-    int encode_audio(const AudioBuffer &input);
+    int encodeAudio(AudioFrame& frame);
 
     // frame should be ready to be sent to the encoder at this point
     int encode(AVFrame* frame, int streamIdx);
@@ -97,8 +98,7 @@ public:
     bool useCodec(const AccountCodecInfo* codec) const noexcept;
 
     unsigned getStreamCount() const;
-
-    void initRecorder(std::shared_ptr<MediaRecorder>& rec);
+    MediaStream getStream(const std::string& name, int streamIdx = -1) const;
 
 private:
     NON_COPYABLE(MediaEncoder);
@@ -122,9 +122,6 @@ private:
     int scaledFrameBufferSize_ = 0;
     bool is_muted = false;
 
-    std::weak_ptr<MediaRecorder> recorder_;
-    bool recordingStarted_ = false;
-
 protected:
     AVDictionary *options_ = nullptr;
     DeviceParams device_;
