@@ -29,11 +29,13 @@
 #include "security/tls_session.h"
 #include "security/diffie-hellman.h"
 #include "sip/sipaccountbase.h"
+#include "dring/datatransfer_interface.h"
 
 #include "noncopyable.h"
 #include "ip_utils.h"
 #include "ring_types.h" // enable_if_base_of
 #include "security/certstore.h"
+#include "scheduled_executor.h"
 
 #include <opendht/dhtrunner.h>
 #include <opendht/default_types.h>
@@ -83,8 +85,8 @@ class RingAccount : public SIPAccountBase {
     public:
         constexpr static const char* const ACCOUNT_TYPE = "RING";
         constexpr static const in_port_t DHT_DEFAULT_PORT = 4222;
-        constexpr static const char* const DHT_DEFAULT_BOOTSTRAP = "bootstrap.ring.cx";
-        constexpr static const char* const DHT_DEFAULT_PROXY = "dhtproxy.ring.cx";
+        constexpr static const char* const DHT_DEFAULT_BOOTSTRAP = "bootstrap.jami.net";
+        constexpr static const char* const DHT_DEFAULT_PROXY = "dhtproxy.jami.net";
         constexpr static const char* const DHT_TYPE_NS = "cx.ring";
 
         /* constexpr */ static const std::pair<uint16_t, uint16_t> DHT_PORT_RANGE;
@@ -99,6 +101,16 @@ class RingAccount : public SIPAccountBase {
         std::shared_ptr<RingAccount const> shared() const {
             return std::static_pointer_cast<RingAccount const>(shared_from_this());
         }
+        std::weak_ptr<RingAccount> weak() {
+            return std::static_pointer_cast<RingAccount>(shared_from_this());
+        }
+        std::weak_ptr<RingAccount const> weak() const {
+            return std::static_pointer_cast<RingAccount const>(shared_from_this());
+        }
+
+        const std::string& getPath() const {
+            return idPath_;
+        }
 
         /**
          * Constructor
@@ -233,7 +245,7 @@ class RingAccount : public SIPAccountBase {
          *      The type of this instance is given in template argument.
          *      This type can be any base class of SIPCall class (included).
          */
-#ifndef RING_UWP
+#ifndef _MSC_VER
         template <class T=SIPCall>
         std::shared_ptr<enable_if_base_of<T, SIPCall> >
         newOutgoingCall(const std::string& toUrl, const std::map<std::string, std::string>& volatileCallDetails = {});
@@ -319,13 +331,22 @@ class RingAccount : public SIPAccountBase {
 #endif
 
         ///
-        /// Send a E2E connection request to a given peer
+        /// Send a E2E connection request to a given peer for the given transfer id
         ///
-        /// /// \param[in] peer_id RingID on request's recipiant
+        /// /// \param[in] peer RingID on request's recipient
+        /// /// \param[in] tid linked outgoing data transfer
         ///
-        void requestPeerConnection(const std::string& peer,
+        void requestPeerConnection(const std::string& peer, const DRing::DataTransferId& tid,
                                    std::function<void(PeerConnection*)> connect_cb);
 
+        ///
+        /// Close a E2E connection between a given peer and a given transfer id.
+        ///
+        /// /// \param[in] peer RingID on request's recipient
+        /// /// \param[in] tid linked outgoing data transfer
+        ///
+        void closePeerConnection(const std::string& peer, const DRing::DataTransferId& tid);
+
         std::vector<std::string> publicAddresses();
 
 
@@ -342,7 +363,8 @@ class RingAccount : public SIPAccountBase {
         void forEachDevice(const dht::InfoHash& to,
                            std::function<void(const std::shared_ptr<RingAccount>&,
                                               const dht::InfoHash&)> op,
-                           std::function<void(bool)> end = {});
+                           std::function<void(const std::shared_ptr<RingAccount>&,
+                                              bool)> end = {});
 
         /**
          * Inform that a potential peer device have been found.
@@ -361,10 +383,18 @@ class RingAccount : public SIPAccountBase {
         void setPushNotificationToken(const std::string& pushDeviceToken = "");
 
         /**
-         * To be called by clients with relevent data when a push notification is received.
+         * To be called by clients with relevant data when a push notification is received.
          */
         void pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data);
 
+        std::string getUserUri() const override;
+
+        /**
+         * Get last messages (should be used to retrieve messages when launching the client)
+         * @param base_timestamp
+         */
+        std::vector<DRing::Message> getLastMessages(const uint64_t& base_timestamp) override;
+
     private:
         NON_COPYABLE(RingAccount);
 
@@ -396,28 +426,23 @@ class RingAccount : public SIPAccountBase {
          */
         static std::pair<std::vector<uint8_t>, dht::InfoHash> computeKeys(const std::string& password, const std::string& pin, bool previous=false);
 
-        /**
-         * Update tracking info when buddy appears offline.
-         *
-         * @param buddy_info_it  An iterator over the map trackedBuddies_
-         */
-        void onTrackedBuddyOffline(std::map<dht::InfoHash, BuddyInfo>::iterator& buddy_info_it);
+        void trackPresence(const dht::InfoHash& h, BuddyInfo& buddy);
 
         /**
          * Update tracking info when buddy appears offline.
-         *
-         * @param buddy_info_it  An iterator over the map trackedBuddies_
-         * @param device_id       The device id
          */
-        void onTrackedBuddyOnline(std::map<dht::InfoHash, BuddyInfo>::iterator& buddy_info_it, const dht::InfoHash& device_id);
+        void onTrackedBuddyOffline(const dht::InfoHash&);
+
+        /**
+         * Update tracking info when buddy appears offline.
+         */
+        void onTrackedBuddyOnline(const dht::InfoHash&);
 
         void doRegister_();
         void incomingCall(dht::IceCandidates&& msg, const std::shared_ptr<dht::crypto::Certificate>& from_cert, const dht::InfoHash& from);
 
         const dht::ValueType USER_PROFILE_TYPE = {9, "User profile", std::chrono::hours(24 * 7)};
 
-        void handleEvents();
-
         void startOutgoingCall(const std::shared_ptr<SIPCall>& call, const std::string toUri);
 
         void onConnectedOutgoingCall(SIPCall& call, const std::string& to_id, IpAddr target);
@@ -473,7 +498,7 @@ class RingAccount : public SIPAccountBase {
 
         dht::InfoHash callKey_;
 
-        void handlePendingCallList();
+        bool handlePendingCallList();
         bool handlePendingCall(PendingCall& pc, bool incoming);
 
         /**
@@ -515,6 +540,7 @@ class RingAccount : public SIPAccountBase {
         void loadContacts();
         void saveContacts() const;
         void updateContact(const dht::InfoHash&, const Contact&);
+        void addContact(const dht::InfoHash&, bool confirmed = false);
 
         // Trust store with Ring account main certificate as the only CA
         dht::crypto::TrustList accountTrust_;
@@ -643,6 +669,9 @@ class RingAccount : public SIPAccountBase {
         void registerDhtAddress(IceTransport&);
 
         std::unique_ptr<DhtPeerConnector> dhtPeerConnector_;
+
+        std::shared_ptr<RepeatedTask> eventHandler {};
+        void checkPendingCallsTask();
 };
 
 static inline std::ostream& operator<< (std::ostream& os, const RingAccount& acc)
