@@ -1,5 +1,5 @@
 /****************************************************************************
- *   Copyright (C) 2013-2016 by Savoir-faire Linux                          *
+ *   Copyright (C) 2013-2018 Savoir-faire Linux                          *
  *   Author : Emmanuel Lepage Vallee <emmanuel.lepage@savoirfairelinux.com> *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
@@ -19,6 +19,7 @@
 
 //Qt
 #include <QtCore/QCoreApplication>
+#include <QtCore/QDateTime>
 
 //DRing
 #include <account_const.h>
@@ -35,10 +36,12 @@
 #include "collectioninterface.h"
 #include "dbus/presencemanager.h"
 #include "globalinstances.h"
+#include "private/contactmethod_p.h"
 #include "interfaces/pixmapmanipulatori.h"
 #include "personmodel.h"
 #include "dbus/configurationmanager.h"
 #include "media/recordingmodel.h"
+#include "media/textrecording.h"
 
 //Private
 #include "private/phonedirectorymodel_p.h"
@@ -46,6 +49,7 @@
 PhoneDirectoryModelPrivate::PhoneDirectoryModelPrivate(PhoneDirectoryModel* parent) : QObject(parent), q_ptr(parent),
 m_CallWithAccount(false),m_pPopularModel(nullptr)
 {
+    connect(&NameDirectory::instance(), &NameDirectory::registeredNameFound, this, &PhoneDirectoryModelPrivate::slotRegisteredNameFound);
 }
 
 PhoneDirectoryModel::PhoneDirectoryModel(QObject* parent) :
@@ -54,8 +58,6 @@ PhoneDirectoryModel::PhoneDirectoryModel(QObject* parent) :
    setObjectName("PhoneDirectoryModel");
    connect(&PresenceManager::instance(),SIGNAL(newBuddyNotification(QString,QString,bool,QString)),d_ptr.data(),
            SLOT(slotNewBuddySubscription(QString,QString,bool,QString)));
-   connect(&ConfigurationManager::instance(), SIGNAL(incomingAccountMessage(QString,QString,MapStringString)), d_ptr.data(),
-           SLOT(slotIncomingAccountMessage(QString, QString, MapStringString)));
 }
 
 PhoneDirectoryModel::~PhoneDirectoryModel()
@@ -245,28 +247,36 @@ QVariant PhoneDirectoryModel::data(const QModelIndex& index, int role ) const
                return number->uid();
          }
          break;
+      case PhoneDirectoryModelPrivate::Columns::REGISTERED_NAME:
+         switch (role) {
+            case Qt::DisplayRole:
+            case Qt::ToolTipRole:
+               return number->registeredName();
+         }
+         break;
    }
    return QVariant();
 }
 
 int PhoneDirectoryModel::rowCount(const QModelIndex& parent ) const
 {
-   if (parent.isValid())
-      return 0;
-   return d_ptr->m_lNumbers.size();
+   return parent.isValid() ? 0 : d_ptr->m_lNumbers.size();
 }
 
 int PhoneDirectoryModel::columnCount(const QModelIndex& parent ) const
 {
-   Q_UNUSED(parent)
-   return 19;
+   return parent.isValid() ? 0 : 20;
 }
 
 Qt::ItemFlags PhoneDirectoryModel::flags(const QModelIndex& index ) const
 {
-   Q_UNUSED(index)
-
    const ContactMethod* number = d_ptr->m_lNumbers[index.row()];
+
+   // Mark the "old" duplicate as disabled. They are now zombies acting as
+   // proxies to the real contact methods.
+   if (number->isDuplicate())
+      return Qt::NoItemFlags;
+
    const bool enabled = !((index.column() == static_cast<int>(PhoneDirectoryModelPrivate::Columns::TRACKED)
       || static_cast<int>(PhoneDirectoryModelPrivate::Columns::PRESENT))
       && number->account() && (!number->account()->supportPresenceSubscribe()));
@@ -294,7 +304,7 @@ QVariant PhoneDirectoryModel::headerData(int section, Qt::Orientation orientatio
    Q_UNUSED(orientation)
    static const QString headers[] = {tr("URI"), tr("Type"), tr("Person"), tr("Account"), tr("State"), tr("Call count"), tr("Week count"),
    tr("Trimester count"), tr("Have Called"), tr("Last used"), tr("Name_count"),tr("Total (in seconds)"), tr("Popularity_index"),
-   tr("Bookmarked"), tr("Tracked"), tr("Has certificate"), tr("Present"), tr("Presence message"), tr("Uid") };
+   tr("Bookmarked"), tr("Tracked"), tr("Has certificate"), tr("Present"), tr("Presence message"), tr("UID"), tr("Registered name") };
    if (role == Qt::DisplayRole) return headers[section];
    return QVariant();
 }
@@ -310,15 +320,16 @@ void PhoneDirectoryModelPrivate::setAccount(ContactMethod* number, Account* acco
    number->setAccount(account);
 
    if (!hasAtSign) {
-      NumberWrapper* wrap = m_hDirectory[strippedUri];
+      const QString extendedUri = strippedUri+'@'+account->hostname();
+      NumberWrapper* wrap = m_hDirectory[extendedUri];
 
       //Let make sure none is created in the future for nothing
       if (!wrap) {
          //It won't be a duplicate as none exist for this URI
-         const QString extendedUri = strippedUri+'@'+account->hostname();
          wrap = new NumberWrapper();
          m_hDirectory    [extendedUri] = wrap;
          m_hSortedNumbers[extendedUri] = wrap;
+         wrap->numbers << number;
 
       }
       else {
@@ -332,6 +343,11 @@ void PhoneDirectoryModelPrivate::setAccount(ContactMethod* number, Account* acco
       wrap->numbers << number;
 
    }
+
+   // for RingIDs, once we set an account, we should perform (another) name lookup, in case the
+   // account has a different name server set from the default
+   if (number->uri().protocolHint() == URI::ProtocolHint::RING)
+      NameDirectory::instance().lookupAddress(number->account(), QString(), number->uri().userinfo());
 }
 
 ///Add new information to existing numbers and try to merge
@@ -419,11 +435,17 @@ ContactMethod* PhoneDirectoryModel::getNumber(const QString& uri, Account* accou
    return getNumber(uri,nullptr,account,type);
 }
 
-///Return/create a number when no information is available
+
 ContactMethod* PhoneDirectoryModel::getNumber(const QString& uri, const QString& type)
 {
-   const URI strippedUri(uri);
-   NumberWrapper* wrap = d_ptr->m_hDirectory[strippedUri];
+    const URI strippedUri(uri);
+    return getNumber(strippedUri, type);
+}
+
+///Return/create a number when no information is available
+ContactMethod* PhoneDirectoryModel::getNumber(const URI& uri, const QString& type)
+{
+   NumberWrapper* wrap = d_ptr->m_hDirectory[uri];
    if (wrap) {
       ContactMethod* nb = wrap->numbers[0];
       if ((!nb->hasType()) && (!type.isEmpty())) {
@@ -433,23 +455,44 @@ ContactMethod* PhoneDirectoryModel::getNumber(const QString& uri, const QString&
    }
 
    //Too bad, lets create one
-   ContactMethod* number = new ContactMethod(strippedUri,NumberCategoryModel::instance().getCategory(type));
+   ContactMethod* number = new ContactMethod(uri, NumberCategoryModel::instance().getCategory(type));
    number->setIndex(d_ptr->m_lNumbers.size());
    d_ptr->m_lNumbers << number;
    connect(number,SIGNAL(callAdded(Call*)),d_ptr.data(),SLOT(slotCallAdded(Call*)));
    connect(number,SIGNAL(changed()),d_ptr.data(),SLOT(slotChanged()));
    connect(number,&ContactMethod::lastUsedChanged,d_ptr.data(), &PhoneDirectoryModelPrivate::slotLastUsedChanged);
    connect(number,&ContactMethod::contactChanged ,d_ptr.data(), &PhoneDirectoryModelPrivate::slotContactChanged);
+   connect(number,&ContactMethod::rebased ,d_ptr.data(), &PhoneDirectoryModelPrivate::slotContactMethodMerged);
+
+    // add the new cm into the historic.
+    for (auto col : CategorizedHistoryModel::instance().collections(CollectionInterface::SupportedFeatures::ADD)) {
+        if (col->id() == "mhb") {
+            QMap<QString,QString> hc;
+            hc[Call::HistoryMapFields::PEER_NUMBER ] = number->uri();
+            // it matters to set a value to hc[Call::HistoryMapFields::CALLID ], but the value itself doesn't matter
+            hc[Call::HistoryMapFields::CALLID ] = "0";
+
+            if (auto fakeCall = Call::buildHistoryCall(hc))
+                col->add(fakeCall);
+            else
+                qDebug() << "buildHistoryCall() has returned an invalid Call object.";
+        }
+    }
 
    const QString hn = number->uri().hostname();
 
    emit layoutChanged();
    if (!wrap) {
       wrap = new NumberWrapper();
-      d_ptr->m_hDirectory[strippedUri] = wrap;
-      d_ptr->m_hSortedNumbers[strippedUri] = wrap;
+      d_ptr->m_hDirectory[uri] = wrap;
+      d_ptr->m_hSortedNumbers[uri] = wrap;
    }
    wrap->numbers << number;
+
+   // perform a username lookup for new CM with RingID
+   if (number->uri().protocolHint() == URI::ProtocolHint::RING)
+      NameDirectory::instance().lookupAddress(number->account(), QString(), number->uri().userinfo());
+
    return number;
 }
 
@@ -551,6 +594,7 @@ ContactMethod* PhoneDirectoryModel::getNumber(const QString& uri, Person* contac
    connect(number,SIGNAL(changed()),d_ptr.data(),SLOT(slotChanged()));
    connect(number,&ContactMethod::lastUsedChanged,d_ptr.data(), &PhoneDirectoryModelPrivate::slotLastUsedChanged);
    connect(number,&ContactMethod::contactChanged ,d_ptr.data(), &PhoneDirectoryModelPrivate::slotContactChanged );
+   connect(number,&ContactMethod::rebased ,d_ptr.data(), &PhoneDirectoryModelPrivate::slotContactMethodMerged);
    if (!wrap) {
       wrap = new NumberWrapper();
       d_ptr->m_hDirectory    [strippedUri] = wrap;
@@ -565,13 +609,21 @@ ContactMethod* PhoneDirectoryModel::getNumber(const QString& uri, Person* contac
             d_ptr->m_hDirectory    [extendedUri] = wrap2;
             d_ptr->m_hSortedNumbers[extendedUri] = wrap2;
          }
-         wrap2->numbers << number;
+
+         if (wrap2)
+            wrap2->numbers << number;
+         else
+            qWarning() << "PhoneDirectoryModel: code path should not be reached, wrap2 is nullptr";
       }
 
    }
    wrap->numbers << number;
    emit layoutChanged();
 
+   // perform a username lookup for new CM with RingID
+   if (number->uri().protocolHint() == URI::ProtocolHint::RING)
+      NameDirectory::instance().lookupAddress(number->account(), QString(), number->uri().userinfo());
+
    return number;
 }
 
@@ -598,6 +650,29 @@ ContactMethod* PhoneDirectoryModel::fromHash(const QString& hash)
    return nullptr;
 }
 
+
+/** Filter the existing CMs for an URI without flooding the model with merge
+ * candidates.
+ *
+ * This should help reduce the number of accidental duplicates once its
+ * usage spread over the code. It also reduce the boilerplate code.
+ **/
+ContactMethod* PhoneDirectoryModel::getExistingNumberIf(const URI& uri, const std::function<bool(const ContactMethod*)>& pred) const
+{
+   // Prevent the most obvious duplicates
+   const URI strippedUri(uri);
+
+   //See if the number is already loaded
+   const NumberWrapper* w = d_ptr->m_hDirectory[strippedUri];
+
+   if (!w)
+      return nullptr;
+
+   const auto iter = std::find_if(std::begin(w->numbers), std::end(w->numbers), pred);
+
+   return (iter != std::end(w->numbers)) ? *iter : nullptr;
+}
+
 QVector<ContactMethod*> PhoneDirectoryModel::getNumbersByPopularity() const
 {
    return d_ptr->m_lPopularityIndex;
@@ -664,10 +739,21 @@ void PhoneDirectoryModelPrivate::slotChanged()
       if (idx<0)
          qDebug() << "Invalid slotChanged() index!" << idx;
 #endif
-      emit q_ptr->dataChanged(q_ptr->index(idx,0),q_ptr->index(idx,static_cast<int>(Columns::UID)));
+      emit q_ptr->dataChanged(q_ptr->index(idx,0),q_ptr->index(idx,static_cast<int>(Columns::REGISTERED_NAME)));
    }
 }
 
+/// Remove
+void PhoneDirectoryModelPrivate::slotContactMethodMerged(ContactMethod* other)
+{
+    // Other == cm when the person they depend on got merged. As a CM is an
+    // "person-lite" this still counts as most code paths care about both. Not
+    // this, so lets ignore the merged persons.
+    auto cm = qobject_cast<ContactMethod*>(sender());
+    if (other != cm)
+        emit q_ptr->contactMethodMerged(cm, other);
+}
+
 void PhoneDirectoryModelPrivate::slotLastUsedChanged(time_t t)
 {
    ContactMethod* cm = qobject_cast<ContactMethod*>(QObject::sender());
@@ -684,16 +770,8 @@ void PhoneDirectoryModelPrivate::slotContactChanged(Person* newContact, Person*
       emit q_ptr->contactChanged(cm, newContact, oldContact);
 }
 
-void PhoneDirectoryModelPrivate::slotIncomingAccountMessage(const QString& account, const QString& from, const MapStringString& msg)
-{
-    if(auto cm = q_ptr->getNumber(from, AccountModel::instance().getById(account.toLatin1()))) {
-        emit q_ptr->incomingMessage(cm, msg);
-    }
-}
-
 void PhoneDirectoryModelPrivate::slotNewBuddySubscription(const QString& accountId, const QString& uri, bool status, const QString& message)
 {
-   qDebug() << "New presence buddy" << uri << status << message;
    ContactMethod* number = q_ptr->getNumber(uri,AccountModel::instance().getById(accountId.toLatin1()));
    number->setPresent(status);
    number->setPresenceMessage(message);
@@ -731,6 +809,80 @@ void PhoneDirectoryModelPrivate::indexNumber(ContactMethod* number, const QStrin
    }
 }
 
+void
+PhoneDirectoryModelPrivate::slotRegisteredNameFound(const Account* account, NameDirectory::LookupStatus status, const QString& address, const QString& name)
+{
+    if (status != NameDirectory::LookupStatus::SUCCESS) {
+        // unsuccessful lookup, so its useless
+        return;
+    }
+    if (address.isEmpty() || name.isEmpty()) {
+        qDebug() << "registered name address (" << address << ") or name (" << name << ") is empty";
+        return;
+    }
+
+    // update relevant contact methods
+    const URI strippedUri(address);
+
+    //See if the number is already loaded
+    auto wrap  = m_hDirectory.value(strippedUri);
+
+    if (wrap) {
+        foreach (ContactMethod* cm, wrap->numbers) {
+            if (cm->account() == account) {
+                cm->incrementAlternativeName(name, QDateTime::currentDateTime().toTime_t());
+                cm->d_ptr->setRegisteredName(name);
+
+                // Add the CM to the directory using the registered name too.
+                // Note that in theory the wrapper can exist already if the
+                // user was either offline in a call attempt or if there is a
+                // collision with a SIP account.
+                if (!m_hDirectory.contains(name)) {
+                    //TODO support multiple name service, use proper URIs for names
+                    auto wrap2 = new NumberWrapper();
+                    m_hDirectory    [name] = wrap2;
+                    m_hSortedNumbers[name] = wrap2;
+                    wrap2->numbers << cm;
+                }
+                else {
+                    auto wrapper = m_hDirectory.value(name);
+                    // Merge the existing CMs now that it is known that the RingId match the username
+                    foreach(ContactMethod* n, wrapper->numbers) {
+
+                        // If the account is the same and (as we know) it is a registered name
+                        // there is 100% porbability of match
+                        const bool compAccount = n->account() &&
+                            n->account() == cm->account();
+
+                        // Less certain, but close enough. We have a contact with a phone
+                        // number corresponding with a registeredName and `ring:` in front.
+                        // it *could* use a different name service. Anyway, for now this
+                        // isn't widespread enough to care.
+                        const bool compContact = (!n->account()) && n->contact() &&
+                            n->uri().schemeType() == URI::SchemeType::RING;
+
+                        if (n != cm && (compAccount || compContact)) {
+                            n->merge(cm);
+                        }
+                    }
+                }
+
+                // Only add it once
+                if (!m_hDirectory[name]->numbers.indexOf(cm)) {
+                    //TODO check if some deduplication can be performed
+                    m_hDirectory[name]->numbers << cm;
+                }
+            } else {
+                qDebug() << "registered name: uri matches but not account" << name << address << account << cm->account();
+            }
+        }
+    } else {
+        // got a registered name for a CM which hasn't been created yet
+        // This can be left as-is to save memory. Those CMs are never freed.
+        // It is generally preferred to create as little as possible.
+    }
+}
+
 int PhoneDirectoryModel::count() const {
    return d_ptr->m_lNumbers.size();
 }
@@ -797,4 +949,16 @@ QAbstractListModel* PhoneDirectoryModel::mostPopularNumberModel() const
    return d_ptr->m_pPopularModel;
 }
 
+/**
+ * @return true if any ContactMethod stored has an unread message. False otherwise
+ */
+bool
+PhoneDirectoryModel::hasUnreadMessage() const
+{
+    return std::any_of(d_ptr->m_lNumbers.begin(), d_ptr->m_lNumbers.end(),
+    [](ContactMethod* cm){
+        return cm->textRecording()->unreadInstantTextMessagingModel()->rowCount() > 0;
+    });
+}
+
 #include <phonedirectorymodel.moc>
