@@ -2,94 +2,94 @@
 <context>
     <name>Account</name>
     <message>
-        <location filename="../src/account.cpp" line="331"/>
+        <location filename="../src/account.cpp" line="307"/>
         <source>Ready</source>
         <extracomment>Account state</extracomment>
         <translation>Gotowe</translation>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="333"/>
+        <location filename="../src/account.cpp" line="309"/>
         <source>Registered</source>
         <extracomment>Account state</extracomment>
         <translation>Zarejestrowany</translation>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="335"/>
-        <source>Not Registered</source>
-        <extracomment>Account state</extracomment>
-        <translation>Nie zarejestrowany</translation>
-    </message>
-    <message>
-        <location filename="../src/account.cpp" line="337"/>
+        <location filename="../src/account.cpp" line="313"/>
         <source>Initializing</source>
         <extracomment>Account state</extracomment>
         <translation>Uruchamianie</translation>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="339"/>
-        <source>Trying...</source>
-        <extracomment>Account state</extracomment>
-        <translation>Próbuje...</translation>
-    </message>
-    <message>
-        <location filename="../src/account.cpp" line="341"/>
+        <location filename="../src/account.cpp" line="317"/>
         <source>Error</source>
         <extracomment>Account state</extracomment>
         <translation>Błąd</translation>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="343"/>
-        <source>Authentication Failed</source>
-        <extracomment>Account state</extracomment>
-        <translation>Błąd w autoryzacji</translation>
-    </message>
-    <message>
-        <location filename="../src/account.cpp" line="345"/>
+        <location filename="../src/account.cpp" line="321"/>
         <source>Network unreachable</source>
         <extracomment>Account state</extracomment>
         <translation>Sieć niedostępna</translation>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="347"/>
+        <location filename="../src/account.cpp" line="323"/>
         <source>Host unreachable</source>
         <extracomment>Account state</extracomment>
         <translation>Host niedostępny</translation>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="349"/>
-        <source>Stun configuration error</source>
+        <location filename="../src/account.cpp" line="311"/>
+        <source>Not registered</source>
         <extracomment>Account state</extracomment>
-        <translation>Błąd konfiguracji Stun</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="351"/>
-        <source>Stun server invalid</source>
+        <location filename="../src/account.cpp" line="315"/>
+        <source>Tryingâ¦</source>
         <extracomment>Account state</extracomment>
-        <translation>Stun serwer nie istnieje</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="353"/>
+        <location filename="../src/account.cpp" line="319"/>
+        <source>Authentication failed</source>
+        <extracomment>Account state</extracomment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/account.cpp" line="325"/>
+        <source>STUN configuration error</source>
+        <extracomment>Account state</extracomment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/account.cpp" line="327"/>
+        <source>STUN server invalid</source>
+        <extracomment>Account state</extracomment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/account.cpp" line="329"/>
         <source>Service unavailable</source>
         <extracomment>Account state</extracomment>
         <translation>Usługa niedostępna</translation>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="355"/>
+        <location filename="../src/account.cpp" line="331"/>
         <source>Unacceptable</source>
         <extracomment>Account state</extracomment>
         <translation>Nie do przyjęcia</translation>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="357"/>
+        <location filename="../src/account.cpp" line="333"/>
         <source>Invalid</source>
         <extracomment>Account state</extracomment>
         <translation>Nieważny</translation>
     </message>
     <message>
-        <location filename="../src/account.cpp" line="359"/>
-        <source>Request Timeout</source>
+        <location filename="../src/account.cpp" line="335"/>
+        <source>Request timeout</source>
         <extracomment>Account state</extracomment>
-        <translation>Prośba przekroczyła czas oczekiwania</translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -100,137 +100,124 @@
         <translation>Konfiguracja</translation>
     </message>
 </context>
-<context>
-    <name>BootstrapModel</name>
-    <message>
-        <location filename="../src/bootstrapmodel.cpp" line="379"/>
-        <source>Hostname</source>
-        <translation>Nazwa hosta</translation>
-    </message>
-    <message>
-        <location filename="../src/bootstrapmodel.cpp" line="381"/>
-        <source>Port</source>
-        <translation>Port</translation>
-    </message>
-</context>
 <context>
     <name>Call</name>
     <message>
-        <location filename="../src/call.cpp" line="720"/>
+        <location filename="../src/call.cpp" line="719"/>
         <source>New</source>
         <extracomment>Call state</extracomment>
         <translation>Nowy</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="723"/>
+        <location filename="../src/call.cpp" line="722"/>
         <source>Ringing</source>
         <extracomment>Call state</extracomment>
         <translation>Dzwonienie</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="726"/>
+        <location filename="../src/call.cpp" line="725"/>
         <source>Calling</source>
         <extracomment>Call state</extracomment>
         <translation>Dzwonienie</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="729"/>
+        <location filename="../src/call.cpp" line="728"/>
         <source>Talking</source>
         <extracomment>Call state</extracomment>
         <translation>Rozmawianie</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="732"/>
+        <location filename="../src/call.cpp" line="731"/>
         <source>Dialing</source>
         <extracomment>Call state</extracomment>
         <translation>Wykręcanie</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="735"/>
+        <location filename="../src/call.cpp" line="734"/>
         <source>Hold</source>
         <extracomment>Call state</extracomment>
         <translation>Czekanie</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="738"/>
+        <location filename="../src/call.cpp" line="737"/>
         <source>Failed</source>
         <extracomment>Call state</extracomment>
         <translation>Nie powiodła się</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="741"/>
+        <location filename="../src/call.cpp" line="740"/>
         <source>Busy</source>
         <extracomment>Call state</extracomment>
         <translation>Zajęty</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="744"/>
+        <location filename="../src/call.cpp" line="743"/>
         <source>Transfer</source>
         <extracomment>Call state</extracomment>
         <translation>Przełaczenie</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="747"/>
+        <location filename="../src/call.cpp" line="746"/>
         <source>Transfer hold</source>
         <extracomment>Call state</extracomment>
         <translation>Czekanie na przełaczenie</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="750"/>
+        <location filename="../src/call.cpp" line="749"/>
         <source>Over</source>
         <extracomment>Call state</extracomment>
         <translation>Koniec</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="753"/>
+        <location filename="../src/call.cpp" line="752"/>
         <source>Error</source>
         <extracomment>Call state</extracomment>
         <translation>Błąd</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="756"/>
-        <location filename="../src/call.cpp" line="861"/>
+        <location filename="../src/call.cpp" line="755"/>
+        <location filename="../src/call.cpp" line="860"/>
         <source>Conference</source>
         <extracomment>Call state</extracomment>
         <translation>Konferencja</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="759"/>
+        <location filename="../src/call.cpp" line="758"/>
         <source>Conference (hold)</source>
         <extracomment>Call state</extracomment>
         <translation>Konferencja (czekanie)</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="762"/>
+        <location filename="../src/call.cpp" line="761"/>
         <source>ERROR</source>
         <extracomment>Call state</extracomment>
         <translation>BŁĄD</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="765"/>
+        <location filename="../src/call.cpp" line="764"/>
         <source>Searching for</source>
         <extracomment>Call state</extracomment>
         <translation>Szukam</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="768"/>
+        <location filename="../src/call.cpp" line="767"/>
         <source>Aborted</source>
         <extracomment>Call state</extracomment>
         <translation>Anulowane</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="771"/>
+        <location filename="../src/call.cpp" line="770"/>
         <source>Communication established</source>
         <extracomment>Call state</extracomment>
         <translation>Połączenie się powiodło </translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="865"/>
+        <location filename="../src/call.cpp" line="864"/>
         <source>Unknown</source>
         <translation>Nieznane</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="2243"/>
+        <location filename="../src/call.cpp" line="2231"/>
         <source>Account: </source>
         <translation>Konto:</translation>
     </message>
@@ -238,7 +225,7 @@
 <context>
     <name>CallModel</name>
     <message>
-        <location filename="../src/callmodel.cpp" line="920"/>
+        <location filename="../src/callmodel.cpp" line="911"/>
         <source>Calls</source>
         <translation>Rozmowy</translation>
     </message>
@@ -246,8 +233,8 @@
 <context>
     <name>CallModelPrivate</name>
     <message>
-        <location filename="../src/callmodel.cpp" line="555"/>
-        <location filename="../src/callmodel.cpp" line="580"/>
+        <location filename="../src/callmodel.cpp" line="546"/>
+        <location filename="../src/callmodel.cpp" line="571"/>
         <source>Invalid account</source>
         <translation>Nieważne konto</translation>
     </message>
@@ -255,12 +242,12 @@
 <context>
     <name>CallPrivate</name>
     <message>
-        <location filename="../src/call.cpp" line="1794"/>
+        <location filename="../src/call.cpp" line="1795"/>
         <source>Aborted</source>
         <translation>Anulowane</translation>
     </message>
     <message>
-        <location filename="../src/call.cpp" line="1815"/>
+        <location filename="../src/call.cpp" line="1816"/>
         <source>No account registered!</source>
         <translation>Nie masz zarejestrowanego konta!</translation>
     </message>
@@ -311,7 +298,7 @@
 <context>
     <name>CategorizedHistoryModel</name>
     <message>
-        <location filename="../src/categorizedhistorymodel.cpp" line="414"/>
+        <location filename="../src/categorizedhistorymodel.cpp" line="412"/>
         <source>History</source>
         <translation>Historia</translation>
     </message>
@@ -391,102 +378,102 @@
 <context>
     <name>HistoryTimeCategoryModel</name>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="40"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="50"/>
         <source>Today</source>
         <translation>Dzisiaj</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="41"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="51"/>
         <source>Yesterday</source>
         <translation>Wczoraj</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="48"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="58"/>
         <source>Two weeks ago</source>
         <translation>Dwa tygodnie temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="49"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="59"/>
         <source>Three weeks ago</source>
         <translation>Trzy tygodnie temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="47"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="57"/>
         <source>A week ago</source>
         <translation>Tydzień temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="50"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="60"/>
         <source>A month ago</source>
         <translation>Miesiąc temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="51"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="61"/>
         <source>Two months ago</source>
         <translation>Dwa miesiące temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="52"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="62"/>
         <source>Three months ago</source>
         <translation>Trzy miesiące temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="53"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="63"/>
         <source>Four months ago</source>
         <translation>Cztery miesiące temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="54"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="64"/>
         <source>Five months ago</source>
         <translation>Pięć miesięcy temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="55"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="65"/>
         <source>Six months ago</source>
         <translation>Sześć miesięcy temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="56"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="66"/>
         <source>Seven months ago</source>
         <translation>Siedem miesięcy temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="57"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="67"/>
         <source>Eight months ago</source>
         <translation>Osiem miesięcy temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="58"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="68"/>
         <source>Nine months ago</source>
         <translation>Dziewięć miesięcy temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="59"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="69"/>
         <source>Ten months ago</source>
         <translation>Dziesięć miesięcy temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="60"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="70"/>
         <source>Eleven months ago</source>
         <translation>Jedenaście miesięcy temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="61"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="71"/>
         <source>Twelve months ago</source>
         <translation>Dwanaście miesięcy temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="62"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="72"/>
         <source>A year ago</source>
         <translation>Rok temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="63"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="73"/>
         <source>Very long time ago</source>
         <translation>Bardzo dawno temu</translation>
     </message>
     <message>
-        <location filename="../src/historytimecategorymodel.cpp" line="64"/>
+        <location filename="../src/historytimecategorymodel.cpp" line="74"/>
         <source>Never</source>
         <translation>Nigdy</translation>
     </message>
@@ -504,7 +491,7 @@
     <message>
         <location filename="../src/macromodel.cpp" line="157"/>
         <source>Macros</source>
-        <translation>Macros</translation>
+        <translation>Makra</translation>
     </message>
     <message>
         <location filename="../src/macromodel.cpp" line="263"/>
@@ -525,24 +512,6 @@
         <translation>Inne</translation>
     </message>
 </context>
-<context>
-    <name>Media::RecordingModel</name>
-    <message>
-        <location filename="../src/media/recordingmodel.cpp" line="189"/>
-        <source>Recordings</source>
-        <translation>Nagrania</translation>
-    </message>
-    <message>
-        <location filename="../src/media/recordingmodel.cpp" line="259"/>
-        <source>Text messages</source>
-        <translation>Wiadomości tekstowe</translation>
-    </message>
-    <message>
-        <location filename="../src/media/recordingmodel.cpp" line="264"/>
-        <source>Audio/Video</source>
-        <translation>Audio/Wideo</translation>
-    </message>
-</context>
 <context>
     <name>NumberCategoryModel</name>
     <message>
@@ -551,33 +520,10 @@
         <translation>Bez kategorii</translation>
     </message>
 </context>
-<context>
-    <name>NumberCompletionModel</name>
-    <message>
-        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
-        <source>URI</source>
-        <translation>URI</translation>
-    </message>
-    <message>
-        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
-        <source>Name</source>
-        <translation>Imię</translation>
-    </message>
-    <message>
-        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
-        <source>Account</source>
-        <translation>Konto</translation>
-    </message>
-    <message>
-        <location filename="../src/numbercompletionmodel.cpp" line="265"/>
-        <source>Weight</source>
-        <translation>Waga</translation>
-    </message>
-</context>
 <context>
     <name>PersonModel</name>
     <message>
-        <location filename="../src/personmodel.cpp" line="171"/>
+        <location filename="../src/personmodel.cpp" line="170"/>
         <source>Persons</source>
         <translation>Osoby</translation>
     </message>
@@ -681,8 +627,8 @@
     </message>
     <message>
         <location filename="../src/phonedirectorymodel.cpp" line="307"/>
-        <source>Uid</source>
-        <translation>Uid</translation>
+        <source>UID</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../src/phonedirectorymodel.cpp" line="307"/>
@@ -755,26 +701,6 @@
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../src/accountstatusmodel.cpp" line="177"/>
-        <source>Message</source>
-        <translation>Wiadomość</translation>
-    </message>
-    <message>
-        <location filename="../src/accountstatusmodel.cpp" line="179"/>
-        <source>Code</source>
-        <translation>Kod</translation>
-    </message>
-    <message>
-        <location filename="../src/accountstatusmodel.cpp" line="181"/>
-        <source>Time</source>
-        <translation>Czas</translation>
-    </message>
-    <message>
-        <location filename="../src/accountstatusmodel.cpp" line="183"/>
-        <source>Counter</source>
-        <translation>Licznik</translation>
-    </message>
     <message>
         <location filename="../src/certificate.cpp" line="42"/>
         <source>Has a private key</source>
@@ -952,8 +878,8 @@
     </message>
     <message>
         <location filename="../src/certificate.cpp" line="104"/>
-        <source>Public key id</source>
-        <translation>Identyfikator klucza publicznego</translation>
+        <source>Public key ID</source>
+        <translation type="unfinished"/>
     </message>
     <message>
         <location filename="../src/certificate.cpp" line="105"/>
@@ -1056,17 +982,10 @@
     </message>
     <message>
         <location filename="../src/fallbackpersoncollection.cpp" line="194"/>
-        <location filename="../src/transitionalpersonbackend.cpp" line="150"/>
         <source>Contact</source>
         <translation>Kontakt</translation>
     </message>
     <message>
-        <location filename="../src/localbookmarkcollection.cpp" line="212"/>
-        <source>Local bookmarks</source>
-        <translation>Lokalne zakładki</translation>
-    </message>
-    <message>
-        <location filename="../src/localbookmarkcollection.cpp" line="217"/>
         <location filename="../src/useractionmodel.cpp" line="532"/>
         <source>Bookmark</source>
         <translation>Zakładka</translation>
@@ -1081,16 +1000,6 @@
         <source>History</source>
         <translation>Historia</translation>
     </message>
-    <message>
-        <location filename="../src/localmacrocollection.cpp" line="190"/>
-        <source>Local macros</source>
-        <translation>Lokalne macros</translation>
-    </message>
-    <message>
-        <location filename="../src/localmacrocollection.cpp" line="195"/>
-        <source>Macro</source>
-        <translation>Macro</translation>
-    </message>
     <message>
         <location filename="../src/localrecordingcollection.cpp" line="101"/>
         <source>Local recordings</source>
@@ -1203,11 +1112,6 @@
         <comment>Default TLS protocol version</comment>
         <translation>Wartość domyślna</translation>
     </message>
-    <message>
-        <location filename="../src/transitionalpersonbackend.cpp" line="145"/>
-        <source>Contact placeholders</source>
-        <translation>Zastępcze kontakty</translation>
-    </message>
     <message>
         <location filename="../src/useractionmodel.cpp" line="517"/>
         <location filename="../src/useractionmodel.cpp" line="759"/>
@@ -1215,69 +1119,68 @@
         <translation>Akceptuj</translation>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="61"/>
-        <location filename="../src/api/call.h" line="77"/>
+        <location filename="../src/api/call.h" line="60"/>
         <location filename="../src/useractionmodel.cpp" line="518"/>
         <location filename="../src/useractionmodel.cpp" line="771"/>
         <source>Hold</source>
         <translation>Czekanie</translation>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="63"/>
+        <location filename="../src/api/call.h" line="62"/>
         <source>Talking</source>
         <translation>Rozmawianie</translation>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="65"/>
+        <location filename="../src/api/call.h" line="64"/>
         <source>ERROR</source>
         <translation>BŁĄD</translation>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="67"/>
-        <source>Outgoing requested</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/api/call.h" line="69"/>
+        <location filename="../src/api/call.h" line="66"/>
         <source>Incoming</source>
         <translation>Przychodzące</translation>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="71"/>
+        <location filename="../src/api/call.h" line="68"/>
         <source>Calling</source>
         <translation>Dzwonienie</translation>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="73"/>
+        <location filename="../src/api/call.h" line="70"/>
         <source>Connecting</source>
         <translation>Łączenie</translation>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="75"/>
+        <location filename="../src/api/call.h" line="72"/>
         <source>Searching</source>
         <translation>Wyszukiwanie</translation>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="79"/>
+        <location filename="../src/api/call.h" line="74"/>
         <source>Inactive</source>
-        <translation type="unfinished"/>
+        <translation>Nieaktywne</translation>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="81"/>
-        <location filename="../src/api/call.h" line="83"/>
+        <location filename="../src/api/call.h" line="76"/>
+        <location filename="../src/api/call.h" line="82"/>
         <source>Finished</source>
+        <translation>Zakończono</translation>
+    </message>
+    <message>
+        <location filename="../src/api/call.h" line="78"/>
+        <source>Timeout</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/api/call.h" line="85"/>
+        <location filename="../src/api/call.h" line="80"/>
+        <source>Peer busy</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/api/call.h" line="84"/>
         <source>Communication established</source>
         <translation>Połączenie się powiodło </translation>
     </message>
-    <message>
-        <location filename="../src/api/call.h" line="87"/>
-        <source>Auto answering</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <location filename="../src/useractionmodel.cpp" line="519"/>
         <source>Mute audio</source>
@@ -1410,68 +1313,60 @@
         <translation>Kolekcja profil peer</translation>
     </message>
     <message>
-        <location filename="../src/conversationmodel.cpp" line="1231"/>
-        <location filename="../src/conversationmodel.cpp" line="1596"/>
-        <location filename="../src/conversationmodel.cpp" line="1846"/>
+        <location filename="../src/conversationmodel.cpp" line="1265"/>
+        <location filename="../src/conversationmodel.cpp" line="1649"/>
+        <location filename="../src/conversationmodel.cpp" line="1909"/>
         <source>Invitation received</source>
-        <translation type="unfinished"/>
+        <translation>Otrzymano zaproszenie</translation>
     </message>
     <message>
-        <location filename="../src/conversationmodel.cpp" line="1232"/>
+        <location filename="../src/conversationmodel.cpp" line="1266"/>
         <source>Contact added</source>
-        <translation type="unfinished"/>
+        <translation>Kontakt dodany</translation>
     </message>
     <message>
-        <location filename="../src/conversationmodel.cpp" line="1267"/>
-        <location filename="../src/conversationmodel.cpp" line="1274"/>
+        <location filename="../src/conversationmodel.cpp" line="1308"/>
+        <location filename="../src/conversationmodel.cpp" line="1315"/>
         <source>Invitation accepted</source>
-        <translation type="unfinished"/>
+        <translation>Zaakceptowano zaproszenie</translation>
     </message>
     <message>
-        <location filename="../src/conversationmodel.cpp" line="1478"/>
+        <location filename="../src/conversationmodel.cpp" line="1524"/>
         <source>ð Outgoing call</source>
-        <translation type="unfinished"/>
+        <translation>ð Połączenie wychodzące</translation>
     </message>
     <message>
-        <location filename="../src/conversationmodel.cpp" line="1480"/>
+        <location filename="../src/conversationmodel.cpp" line="1526"/>
         <source>ð Incoming call</source>
-        <translation type="unfinished"/>
+        <translation>ð Połączenie przychodzące</translation>
     </message>
     <message>
-        <location filename="../src/conversationmodel.cpp" line="1493"/>
+        <location filename="../src/conversationmodel.cpp" line="1539"/>
         <source>ð Outgoing call - </source>
-        <translation type="unfinished"/>
+        <translation>ð Połączenie wychodzące -</translation>
     </message>
     <message>
-        <location filename="../src/conversationmodel.cpp" line="1496"/>
+        <location filename="../src/conversationmodel.cpp" line="1542"/>
         <source>ð Incoming call - </source>
-        <translation type="unfinished"/>
+        <translation>ð Połączenie przychodzące -</translation>
     </message>
     <message>
-        <location filename="../src/conversationmodel.cpp" line="1500"/>
+        <location filename="../src/conversationmodel.cpp" line="1546"/>
         <source>ð½ Missed outgoing call</source>
-        <translation type="unfinished"/>
+        <translation>ð½ Nieodebrane połączenie wychodzące</translation>
     </message>
     <message>
-        <location filename="../src/conversationmodel.cpp" line="1502"/>
+        <location filename="../src/conversationmodel.cpp" line="1548"/>
         <source>ð½ Missed incoming call</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>RecentModel</name>
-    <message>
-        <location filename="../src/recentmodel.cpp" line="614"/>
-        <source>Recent persons</source>
-        <translation>Niedawne osóby</translation>
+        <translation>ð½ Nieodebrane połączenia przychodzące</translation>
     </message>
 </context>
 <context>
     <name>RingDeviceModel</name>
     <message>
         <location filename="../src/ringdevicemodel.cpp" line="110"/>
-        <source>Id</source>
-        <translation>Id</translation>
+        <source>ID</source>
+        <translation>ID</translation>
     </message>
     <message>
         <location filename="../src/ringdevicemodel.cpp" line="112"/>
@@ -1513,4 +1408,53 @@
         <translation>PLIK</translation>
     </message>
 </context>
+<context>
+    <name>lrc::ContactModelPimpl</name>
+    <message>
+        <location filename="../src/contactmodel.cpp" line="393"/>
+        <source>Searchingâ¦</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/contactmodel.cpp" line="747"/>
+        <source>Invalid ID</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/contactmodel.cpp" line="750"/>
+        <source>Not found</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/contactmodel.cpp" line="753"/>
+        <source>Couldn&apos;t lookupâ¦</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>lrc::api::ContactModel</name>
+    <message>
+        <location filename="../src/contactmodel.cpp" line="364"/>
+        <source>Bad URI scheme</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>media::RecordingModel</name>
+    <message>
+        <location filename="../src/media/recordingmodel.cpp" line="189"/>
+        <source>Recordings</source>
+        <translation>Nagrania</translation>
+    </message>
+    <message>
+        <location filename="../src/media/recordingmodel.cpp" line="259"/>
+        <source>Text messages</source>
+        <translation>Wiadomości tekstowe</translation>
+    </message>
+    <message>
+        <location filename="../src/media/recordingmodel.cpp" line="264"/>
+        <source>Audio/Video</source>
+        <translation>Audio/Wideo</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
